@@ -19,12 +19,12 @@ def prep_npe2():
 
     npe2_version = version("npe2")
 
-    check_call("rm -rf npe2".split())
+    check_call(f"rm -rf {NPE}".split())
     check_call(f"git clone https://github.com/napari/npe2 {NPE}".split())
     if not parse(npe2_version).is_devrelease:
         check_call(f"git checkout tags/v{npe2_version}".split(), cwd=NPE)
-    check_call([sys.executable, "npe2/_docs/render.py", DOCS / 'plugins'])
-    check_call("rm -rf npe2".split())
+    check_call([sys.executable, f"{NPE}/_docs/render.py", DOCS / 'plugins'])
+    check_call(f"rm -rf {NPE}".split())
 
 
 def main():
