@@ -1,7 +1,7 @@
 import os
 import random
 import sys
-from collections import namedtuple
+from typing import NamedTuple, Optional, Type
 
 import numpy as np
 import pytest
@@ -34,50 +34,68 @@ from napari.components import ViewerModel
 from napari.layers import (
     Image,
     Labels,
+    Layer,
     Points,
     Shapes,
     Surface,
     Tracks,
     Vectors,
 )
+from napari.utils.colormaps import DirectLabelColormap
+
+
+class LayerTypeWithData(NamedTuple):
+    type: Type[Layer]
+    data: np.ndarray
+    colormap: Optional[DirectLabelColormap]
+    properties: Optional[dict]
+    expected_isinstance: Type[QtLayerControlsContainer]
+
 
 np.random.seed(0)
-LayerTypeWithData = namedtuple(
-    'LayerTypeWithData',
-    ['type', 'data', 'color', 'properties', 'expected_isinstance'],
-)
+
+
 _IMAGE = LayerTypeWithData(
     type=Image,
     data=np.random.rand(8, 8),
-    color=None,
+    colormap=None,
     properties=None,
     expected_isinstance=QtImageControls,
 )
-_LABELS_WITH_COLOR = LayerTypeWithData(
+_LABELS_WITH_DIRECT_COLORMAP = LayerTypeWithData(
     type=Labels,
     data=np.random.randint(5, size=(10, 15)),
-    color={1: 'white', 2: 'blue', 3: 'green', 4: 'red', 5: 'yellow'},
+    colormap=DirectLabelColormap(
+        color_dict={
+            1: 'white',
+            2: 'blue',
+            3: 'green',
+            4: 'red',
+            5: 'yellow',
+            None: "black",
+        }
+    ),
     properties=None,
     expected_isinstance=QtLabelsControls,
 )
 _LABELS = LayerTypeWithData(
     type=Labels,
     data=np.random.randint(5, size=(10, 15)),
-    color=None,
+    colormap=None,
     properties=None,
     expected_isinstance=QtLabelsControls,
 )
 _POINTS = LayerTypeWithData(
     type=Points,
     data=np.random.random((5, 2)),
-    color=None,
+    colormap=None,
     properties=None,
     expected_isinstance=QtPointsControls,
 )
 _SHAPES = LayerTypeWithData(
     type=Shapes,
     data=np.random.random((10, 4, 2)),
-    color=None,
+    colormap=None,
     properties=None,
     expected_isinstance=QtShapesControls,
 )
@@ -88,14 +106,14 @@ _SURFACE = LayerTypeWithData(
         np.random.randint(10, size=(6, 3)),
         np.random.random(10),
     ),
-    color=None,
+    colormap=None,
     properties=None,
     expected_isinstance=QtSurfaceControls,
 )
 _TRACKS = LayerTypeWithData(
     type=Tracks,
     data=np.zeros((2, 4)),
-    color=None,
+    colormap=None,
     properties={
         'track_id': [0, 0],
         'time': [0, 0],
@@ -106,7 +124,7 @@ _TRACKS = LayerTypeWithData(
 _VECTORS = LayerTypeWithData(
     type=Vectors,
     data=np.zeros((2, 2, 2)),
-    color=None,
+    colormap=None,
     properties=None,
     expected_isinstance=QtVectorsControls,
 )
@@ -116,9 +134,10 @@ _LINES_DATA = np.random.random((6, 2, 2))
 @pytest.fixture
 def create_layer_controls(qtbot):
     def _create_layer_controls(layer_type_with_data):
-        if layer_type_with_data.color:
+        if layer_type_with_data.colormap:
             layer = layer_type_with_data.type(
-                layer_type_with_data.data, color=layer_type_with_data.color
+                layer_type_with_data.data,
+                colormap=layer_type_with_data.colormap,
             )
         elif layer_type_with_data.properties:
             layer = layer_type_with_data.type(
@@ -139,7 +158,7 @@ def create_layer_controls(qtbot):
 @pytest.mark.parametrize(
     'layer_type_with_data',
     [
-        _LABELS_WITH_COLOR,
+        _LABELS_WITH_DIRECT_COLORMAP,
         _LABELS,
         _IMAGE,
         _POINTS,
@@ -148,6 +167,16 @@ def create_layer_controls(qtbot):
         _TRACKS,
         _VECTORS,
     ],
+    ids=[
+        "labels_with_direct_colormap",
+        "labels_with_auto_colormap",
+        "image",
+        "points",
+        "shapes",
+        "surface",
+        "tracks",
+        "vectors",
+    ],
 )
 @pytest.mark.qt_no_exception_capture
 @pytest.mark.skipif(os.environ.get("MIN_REQ", "0") == "1", reason="min req")
@@ -178,30 +207,38 @@ def test_create_layer_controls(
             qcombobox.setCurrentIndex(qcombobox_initial_idx)
 
 
-if sys.version_info[:2] == (3, 11) and (
+skip_predicate = sys.version_info >= (3, 11) and (
     qtpy.API == 'pyqt5' or qtpy.API == 'pyqt6'
-):
-    test_data = []
-else:
-    # those 2 fail on 3.11 + pyqt5 and pyqt6 with a segfault that can't be caught by
-    # pytest in qspinbox.setValue(value)
-    # See: https://github.com/napari/napari/pull/5439
-    test_data = [_LABELS_WITH_COLOR, _LABELS]
-
-
-test_data += [
-    _IMAGE,
-    _POINTS,
-    _SHAPES,
-    _SURFACE,
-    _TRACKS,
-    _VECTORS,
-]
+)
 
 
 @pytest.mark.parametrize(
     'layer_type_with_data',
-    test_data,
+    [
+        # those 2 fail on 3.11 + pyqt5 and pyqt6 with a segfault that can't be caught by
+        # pytest in qspinbox.setValue(value)
+        # See: https://github.com/napari/napari/pull/5439
+        pytest.param(
+            _LABELS_WITH_DIRECT_COLORMAP,
+            marks=pytest.mark.skipif(
+                skip_predicate,
+                reason='segfault on Python 3.11+ and pyqt5 or Pyqt6',
+            ),
+        ),
+        pytest.param(
+            _LABELS,
+            marks=pytest.mark.skipif(
+                skip_predicate,
+                reason='segfault on Python 3.11+ and pyqt5 or Pyqt6',
+            ),
+        ),
+        _IMAGE,
+        _POINTS,
+        _SHAPES,
+        _SURFACE,
+        _TRACKS,
+        _VECTORS,
+    ],
 )
 @pytest.mark.qt_no_exception_capture
 @pytest.mark.skipif(os.environ.get("MIN_REQ", "0") == "1", reason="min req")
@@ -210,6 +247,7 @@ def test_create_layer_controls_spin(
 ):
     # create layer controls widget
     ctrl = create_layer_controls(layer_type_with_data)
+    qtbot.addWidget(ctrl)
 
     # check create widget corresponds to the expected class for each type of layer
     assert isinstance(ctrl, layer_type_with_data.expected_isinstance)
@@ -259,7 +297,7 @@ def test_create_layer_controls_spin(
                 assert any(
                     expected_error in captured.err
                     for expected_error in expected_errors
-                ), captured.err
+                ), f"value: {value}, range {value_range}\nerr: {captured.err}"
 
         assert qspinbox.value() in [qspinbox_max, qspinbox_max - 1]
         qspinbox.setValue(qspinbox_initial_value)
@@ -268,7 +306,7 @@ def test_create_layer_controls_spin(
 @pytest.mark.parametrize(
     'layer_type_with_data',
     [
-        _LABELS_WITH_COLOR,
+        _LABELS_WITH_DIRECT_COLORMAP,
         _LABELS,
         _IMAGE,
         _POINTS,
@@ -350,7 +388,7 @@ def test_create_layer_controls_qslider(
 @pytest.mark.parametrize(
     'layer_type_with_data',
     [
-        _LABELS_WITH_COLOR,
+        _LABELS_WITH_DIRECT_COLORMAP,
         _LABELS,
         _IMAGE,
         _POINTS,
