@@ -1,12 +1,18 @@
+from typing import TYPE_CHECKING
+
 import numpy as np
 from qtpy.QtCore import Qt
 from qtpy.QtWidgets import QCheckBox, QComboBox, QDoubleSpinBox, QLabel
 
-from ...layers.utils._color_manager_constants import ColorMode
-from ...utils.translations import trans
-from ..utils import qt_signals_blocked
-from ..widgets.qt_color_swatch import QColorSwatchEdit
-from .qt_layer_controls_base import QtLayerControls
+from napari._qt.layer_controls.qt_layer_controls_base import QtLayerControls
+from napari._qt.utils import qt_signals_blocked
+from napari._qt.widgets.qt_color_swatch import QColorSwatchEdit
+from napari.layers.utils._color_manager_constants import ColorMode
+from napari.layers.vectors._vectors_constants import VECTORSTYLE_TRANSLATIONS
+from napari.utils.translations import trans
+
+if TYPE_CHECKING:
+    import napari.layers
 
 
 class QtVectorsControls(QtLayerControls):
@@ -21,18 +27,16 @@ class QtVectorsControls(QtLayerControls):
     ----------
     edge_color_label : qtpy.QtWidgets.QLabel
         Label for edgeColorSwatch
-    edgeColorSwatch : qtpy.QtWidgets.QFrame
-        Color swatch showing display color of vectors.
-    edgeComboBox : qtpy.QtWidgets.QComboBox
-        Dropdown widget to select display color for vectors.
+    edgeColorEdit : QColorSwatchEdit
+        Widget to select display color for vectors.
+    vector_style_comboBox : qtpy.QtWidgets.QComboBox
+        Dropdown widget to select vector_style for the vectors.
     color_mode_comboBox : qtpy.QtWidgets.QComboBox
         Dropdown widget to select edge_color_mode for the vectors.
     color_prop_box : qtpy.QtWidgets.QComboBox
         Dropdown widget to select _edge_color_property for the vectors.
     edge_prop_label : qtpy.QtWidgets.QLabel
         Label for color_prop_box
-    grid_layout : qtpy.QtWidgets.QGridLayout
-        Layout of Qt widget controls for the layer.
     layer : napari.layers.Vectors
         An instance of a napari Vectors layer.
     outOfSliceCheckBox : qtpy.QtWidgets.QCheckBox
@@ -42,27 +46,23 @@ class QtVectorsControls(QtLayerControls):
         Multiplicative factor on projections for length of all vectors.
     widthSpinBox : qtpy.QtWidgets.QDoubleSpinBox
         Spin box widget controlling edge line width of vectors.
+    vector_style_comboBox : qtpy.QtWidgets.QComboBox
+        Dropdown widget to select vector_style for the vectors.
     """
 
-    def __init__(self, layer):
-        super().__init__(layer)
+    layer: 'napari.layers.Vectors'
 
-        self.layer.events.edge_width.connect(self._on_edge_width_change)
-        self.layer.events.length.connect(self._on_length_change)
-        self.layer.events.out_of_slice_display.connect(
-            self._on_out_of_slice_display_change
-        )
-        self.layer.events.edge_color_mode.connect(
-            self._on_edge_color_mode_change
-        )
-        self.layer.events.edge_color.connect(self._on_edge_color_change)
+    def __init__(self, layer) -> None:
+        super().__init__(layer)
 
         # dropdown to select the property for mapping edge_color
         color_properties = self._get_property_values()
-        color_prop_box = QComboBox(self)
-        color_prop_box.activated[str].connect(self.change_edge_color_property)
-        color_prop_box.addItems(color_properties)
-        self.color_prop_box = color_prop_box
+        self.color_prop_box = QComboBox(self)
+        self.color_prop_box.currentTextChanged.connect(
+            self.change_edge_color_property
+        )
+        self.color_prop_box.addItems(color_properties)
+
         self.edge_prop_label = QLabel(trans._('edge property:'))
 
         # vector direct color mode adjustment and widget
@@ -76,12 +76,26 @@ class QtVectorsControls(QtLayerControls):
         self.edge_color_label = QLabel(trans._('edge color:'))
         self._on_edge_color_change()
 
+        # dropdown to select the edge display vector_style
+        vector_style_comboBox = QComboBox(self)
+        for index, (data, text) in enumerate(VECTORSTYLE_TRANSLATIONS.items()):
+            data = data.value
+            vector_style_comboBox.addItem(text, data)
+            if data == self.layer.vector_style:
+                vector_style_comboBox.setCurrentIndex(index)
+
+        self.vector_style_comboBox = vector_style_comboBox
+        self.vector_style_comboBox.currentTextChanged.connect(
+            self.change_vector_style
+        )
+
         # dropdown to select the edge color mode
-        colorModeComboBox = QComboBox(self)
+        self.color_mode_comboBox = QComboBox(self)
         color_modes = [e.value for e in ColorMode]
-        colorModeComboBox.addItems(color_modes)
-        colorModeComboBox.activated[str].connect(self.change_edge_color_mode)
-        self.color_mode_comboBox = colorModeComboBox
+        self.color_mode_comboBox.addItems(color_modes)
+        self.color_mode_comboBox.currentTextChanged.connect(
+            self.change_edge_color_mode
+        )
         self._on_edge_color_mode_change()
 
         # line width in pixels
@@ -108,10 +122,13 @@ class QtVectorsControls(QtLayerControls):
         out_of_slice_cb.stateChanged.connect(self.change_out_of_slice)
         self.outOfSliceCheckBox = out_of_slice_cb
 
-        self.layout().addRow(trans._('opacity:'), self.opacitySlider)
+        self.layout().addRow(self.opacityLabel, self.opacitySlider)
         self.layout().addRow(trans._('width:'), self.widthSpinBox)
         self.layout().addRow(trans._('length:'), self.lengthSpinBox)
         self.layout().addRow(trans._('blending:'), self.blendComboBox)
+        self.layout().addRow(
+            trans._('vector style:'), self.vector_style_comboBox
+        )
         self.layout().addRow(
             trans._('edge color mode:'), self.color_mode_comboBox
         )
@@ -119,18 +136,29 @@ class QtVectorsControls(QtLayerControls):
         self.layout().addRow(self.edge_prop_label, self.color_prop_box)
         self.layout().addRow(trans._('out of slice:'), self.outOfSliceCheckBox)
 
-    def change_edge_color_property(self, property: str):
+        self.layer.events.edge_width.connect(self._on_edge_width_change)
+        self.layer.events.length.connect(self._on_length_change)
+        self.layer.events.out_of_slice_display.connect(
+            self._on_out_of_slice_display_change
+        )
+        self.layer.events.vector_style.connect(self._on_vector_style_change)
+        self.layer.events.edge_color_mode.connect(
+            self._on_edge_color_mode_change
+        )
+        self.layer.events.edge_color.connect(self._on_edge_color_change)
+
+    def change_edge_color_property(self, property_name: str):
         """Change edge_color_property of vectors on the layer model.
         This property is the property the edge color is mapped to.
 
         Parameters
         ----------
-        property : str
+        property_name : str
             property to map the edge color to
         """
         mode = self.layer.edge_color_mode
         try:
-            self.layer.edge_color = property
+            self.layer.edge_color = property_name
             self.layer.edge_color_mode = mode
         except TypeError:
             # if the selected property is the wrong type for the current color mode
@@ -138,6 +166,17 @@ class QtVectorsControls(QtLayerControls):
             self._on_edge_color_mode_change()
             raise
 
+    def change_vector_style(self, vector_style: str):
+        """Change vector style of vectors on the layer model.
+
+        Parameters
+        ----------
+        vector_style : str
+            Name of vectors style, eg: 'line', 'triangle' or 'arrow'.
+        """
+        with self.layer.events.vector_style.blocker():
+            self.layer.vector_style = vector_style
+
     def change_edge_color_mode(self, mode: str):
         """Change edge color mode of vectors on the layer model.
 
@@ -153,8 +192,9 @@ class QtVectorsControls(QtLayerControls):
                 self._update_edge_color_gui(mode)
 
             except ValueError:
-                # if the color mode was invalid, revert to the old mode
+                # if the color mode was invalid, revert to the old mode (layer and GUI)
                 self.layer.edge_color_mode = old_mode
+                self.color_mode_comboBox.setCurrentText(old_mode)
                 raise
 
     def change_edge_color_direct(self, color: np.ndarray):
@@ -198,13 +238,12 @@ class QtVectorsControls(QtLayerControls):
 
         Parameters
         ----------
-        state : QCheckBox
-            Checkbox to indicate whether to render out of slice.
+        state : int
+             Integer value of Qt.CheckState that indicates the check state of outOfSliceCheckBox
         """
-        if state == Qt.Checked:
-            self.layer.out_of_slice_display = True
-        else:
-            self.layer.out_of_slice_display = False
+        self.layer.out_of_slice_display = (
+            Qt.CheckState(state) == Qt.CheckState.Checked
+        )
 
     def _update_edge_color_gui(self, mode: str):
         """Update the GUI element associated with edge_color.
@@ -216,7 +255,7 @@ class QtVectorsControls(QtLayerControls):
             The new edge_color mode the GUI needs to be updated for.
             Should be: 'direct', 'cycle', 'colormap'
         """
-        if mode in ('cycle', 'colormap'):
+        if mode in {'cycle', 'colormap'}:
             self.edgeColorEdit.setHidden(True)
             self.edge_color_label.setHidden(True)
             self.color_prop_box.setHidden(False)
@@ -259,6 +298,15 @@ class QtVectorsControls(QtLayerControls):
         with self.layer.events.edge_width.blocker():
             self.widthSpinBox.setValue(self.layer.edge_width)
 
+    def _on_vector_style_change(self):
+        """Receive layer model vector style change event & update dropdown."""
+        with self.layer.events.vector_style.blocker():
+            vector_style = self.layer.vector_style
+            index = self.vector_style_comboBox.findText(
+                vector_style, Qt.MatchFixedString
+            )
+            self.vector_style_comboBox.setCurrentIndex(index)
+
     def _on_edge_color_mode_change(self):
         """Receive layer model edge color mode change event & update dropdown."""
         with qt_signals_blocked(self.color_mode_comboBox):
