@@ -6,7 +6,7 @@ from qtpy.QtWidgets import QAction, QMenu
 if TYPE_CHECKING:
     from typing_extensions import TypedDict
 
-    from ...utils.events import EventEmitter
+    from napari.utils.events import EventEmitter
 
     try:
         from qtpy.QtCore import SignalInstance
@@ -117,7 +117,7 @@ class NapariMenu(QMenu):
 
     _INSTANCES: List['NapariMenu'] = []
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         self._INSTANCES.append(self)
 
