@@ -9,17 +9,17 @@ from typing import TYPE_CHECKING
 from qtpy.QtCore import QTimer
 from qtpy.QtWidgets import QFileDialog
 
-from ...utils import perf
-from ...utils.history import get_save_history, update_save_history
-from ...utils.translations import trans
-from ._util import NapariMenu, populate_menu
+from napari._qt.menus._util import NapariMenu, populate_menu
+from napari.utils import perf
+from napari.utils.history import get_save_history, update_save_history
+from napari.utils.translations import trans
 
 if TYPE_CHECKING:
-    from ..qt_main_window import Window
+    from napari._qt.qt_main_window import Window
 
 
 class DebugMenu(NapariMenu):
-    def __init__(self, window: 'Window'):
+    def __init__(self, window: 'Window') -> None:
         self._win = window
         super().__init__(trans._('&Debug'), window._qt_window)
         self._perf_menu = NapariMenu(trans._("Performance Trace"), self)
@@ -62,9 +62,9 @@ class DebugMenu(NapariMenu):
         hist = get_save_history()
         dlg.setHistory(hist)
         filename, _ = dlg.getSaveFileName(
-            parent=viewer,
-            caption=trans._('Record performance trace file'),
-            directory=hist[0],
+            viewer,  # parent
+            trans._('Record performance trace file'),  # caption
+            hist[0],  # directory in PyQt, dir in PySide
             filter=trans._("Trace Files (*.json)"),
         )
         if filename:
