@@ -6,25 +6,29 @@ from contextlib import contextmanager
 from typing import TYPE_CHECKING
 from warnings import warn
 
-from qtpy import PYQT5
-from qtpy.QtCore import Qt
+from qtpy import PYQT5, PYSIDE2
+from qtpy.QtCore import QDir, Qt
 from qtpy.QtGui import QIcon
 from qtpy.QtWidgets import QApplication
 
-from .. import __version__
-from ..settings import get_settings
-from ..utils import config, perf
-from ..utils.notifications import (
+from napari import Viewer, __version__
+from napari._qt.dialogs.qt_notification import NapariQtNotification
+from napari._qt.qt_event_filters import QtToolTipEventFilter
+from napari._qt.qthreading import (
+    register_threadworker_processors,
+    wait_for_workers_to_quit,
+)
+from napari._qt.utils import _maybe_allow_interrupt
+from napari.resources._icons import _theme_path
+from napari.settings import get_settings
+from napari.utils import config, perf
+from napari.utils.notifications import (
     notification_manager,
     show_console_notification,
 )
-from ..utils.perf import perf_config
-from ..utils.translations import trans
-from .dialogs.qt_notification import NapariQtNotification
-from .qt_event_filters import QtToolTipEventFilter
-from .qt_resources import _register_napari_resources
-from .qthreading import wait_for_workers_to_quit
-from .utils import _maybe_allow_interrupt
+from napari.utils.perf import perf_config
+from napari.utils.theme import _themes
+from napari.utils.translations import trans
 
 if TYPE_CHECKING:
     from IPython import InteractiveShell
@@ -116,28 +120,37 @@ def get_app(
     if app:
         set_values.discard("ipy_interactive")
         if set_values:
-
             warn(
                 trans._(
                     "QApplication already existed, these arguments to to 'get_app' were ignored: {args}",
                     deferred=True,
                     args=set_values,
-                )
+                ),
+                stacklevel=2,
             )
         if perf_config and perf_config.trace_qt_events:
             warn(
                 trans._(
                     "Using NAPARI_PERFMON with an already-running QtApp (--gui qt?) is not supported.",
                     deferred=True,
-                )
+                ),
+                stacklevel=2,
             )
 
     else:
         # automatically determine monitor DPI.
-        # Note: this MUST be set before the QApplication is instantiated
-        if PYQT5:
-            QApplication.setAttribute(Qt.AA_EnableHighDpiScaling)
-            QApplication.setAttribute(Qt.AA_UseHighDpiPixmaps)
+        # Note: this MUST be set before the QApplication is instantiated. Also, this
+        # attributes need to be applied only to Qt5 bindings (PyQt5 and PySide2)
+        # since the High DPI scaling attributes are deactivated by default while on Qt6
+        # they are deprecated and activated by default. For more info see:
+        # https://doc.qt.io/qtforpython-6/gettingstarted/porting_from2.html#class-function-deprecations
+        if PYQT5 or PYSIDE2:
+            QApplication.setAttribute(
+                Qt.ApplicationAttribute.AA_EnableHighDpiScaling
+            )
+            QApplication.setAttribute(
+                Qt.ApplicationAttribute.AA_UseHighDpiPixmaps
+            )
 
         argv = sys.argv.copy()
         if sys.platform == "darwin" and not argv[0].endswith("napari"):
@@ -147,7 +160,9 @@ def get_app(
             argv[0] = "napari"
 
         if perf_config and perf_config.trace_qt_events:
-            from .perf.qt_event_tracing import QApplicationWithTracing
+            from napari._qt.perf.qt_event_tracing import (
+                QApplicationWithTracing,
+            )
 
             app = QApplicationWithTracing(argv)
         else:
@@ -190,9 +205,18 @@ def get_app(
         # workers at shutdown.
         app.aboutToQuit.connect(wait_for_workers_to_quit)
 
-        # this will register all of our resources (icons) with Qt, so that they
-        # can be used in qss files and elsewhere.
-        _register_napari_resources()
+        # Setup search paths for currently installed themes.
+        for name in _themes:
+            QDir.addSearchPath(f'theme_{name}', str(_theme_path(name)))
+
+        # When a new theme is added, at it to the search path.
+        @_themes.events.changed.connect
+        @_themes.events.added.connect
+        def _(event):
+            name = event.key
+            QDir.addSearchPath(f'theme_{name}', str(_theme_path(name)))
+
+        register_threadworker_processors()
 
     _app_ref = app  # prevent garbage collection
 
@@ -204,6 +228,8 @@ def get_app(
 
 def quit_app():
     """Close all windows and quit the QApplication if napari started it."""
+    for v in list(Viewer._instances):
+        v.close()
     QApplication.closeAllWindows()
     # if we started the application then the app will be named 'napari'.
     if (
@@ -227,13 +253,13 @@ def quit_app():
 
     if config.monitor:
         # Stop the monitor service if we were using it
-        from ..components.experimental.monitor import monitor
+        from napari.components.experimental.monitor import monitor
 
         monitor.stop()
 
     if config.async_loading:
         # Shutdown the chunkloader
-        from ..components.experimental.chunk import chunk_loader
+        from napari.components.experimental.chunk import chunk_loader
 
         chunk_loader.shutdown()
 
@@ -268,18 +294,19 @@ def gui_qt(*, startup_logo=False, gui_exceptions=False, force=False):
             deferred=True,
         ),
         FutureWarning,
+        stacklevel=2,
     )
 
     app = get_app()
     splash = None
     if startup_logo and app.applicationName() == 'napari':
-        from .widgets.qt_splash_screen import NapariSplashScreen
+        from napari._qt.widgets.qt_splash_screen import NapariSplashScreen
 
         splash = NapariSplashScreen()
         splash.close()
     try:
         yield app
-    except Exception:
+    except Exception:  # noqa: BLE001
         notification_manager.receive_error(*sys.exc_info())
     run(force=force, gui_exceptions=gui_exceptions, _func_name='gui_qt')
 
@@ -381,7 +408,8 @@ def run(
                 "Refusing to run a QApplication with no topLevelWidgets. To run the app anyway, use `{_func_name}(force=True)`",
                 deferred=True,
                 _func_name=_func_name,
-            )
+            ),
+            stacklevel=2,
         )
         return
 
@@ -395,7 +423,8 @@ def run(
                 deferred=True,
                 _func_name=_func_name,
                 max_loop_level=loops + 1,
-            )
+            ),
+            stacklevel=2,
         )
         return
     with notification_manager, _maybe_allow_interrupt(app):
