@@ -7,11 +7,14 @@ from qtpy.QtWidgets import (
     QHBoxLayout,
     QLabel,
     QProgressBar,
+    QPushButton,
     QVBoxLayout,
     QWidget,
 )
 
-from ...utils.progress import progress
+from napari.utils.migrations import rename_argument
+from napari.utils.progress import cancelable_progress, progress
+from napari.utils.translations import trans
 
 
 class QtLabeledProgressBar(QWidget):
@@ -21,19 +24,23 @@ class QtLabeledProgressBar(QWidget):
         self, parent: Optional[QWidget] = None, prog: progress = None
     ) -> None:
         super().__init__(parent)
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setAttribute(QtCore.Qt.WidgetAttribute.WA_DeleteOnClose)
 
         self.progress = prog
 
         self.qt_progress_bar = QProgressBar()
         self.description_label = QLabel()
         self.eta_label = QLabel()
+        self.cancel_button = QPushButton(trans._('Cancel'))
+        self.cancel_button.clicked.connect(self._cancel)
+        self.cancel_button.setVisible(isinstance(prog, cancelable_progress))
         base_layout = QVBoxLayout()
 
         pbar_layout = QHBoxLayout()
         pbar_layout.addWidget(self.description_label)
         pbar_layout.addWidget(self.qt_progress_bar)
         pbar_layout.addWidget(self.eta_label)
+        pbar_layout.addWidget(self.cancel_button)
         base_layout.addLayout(pbar_layout)
 
         line = QFrame(self)
@@ -43,8 +50,20 @@ class QtLabeledProgressBar(QWidget):
 
         self.setLayout(base_layout)
 
-    def setRange(self, min, max):
-        self.qt_progress_bar.setRange(min, max)
+    @rename_argument(
+        from_name="min",
+        to_name="min_val",
+        version="0.6.0",
+        since_version="0.4.18",
+    )
+    @rename_argument(
+        from_name="max",
+        to_name="max_val",
+        version="0.6.0",
+        since_version="0.4.18",
+    )
+    def setRange(self, min_val, max_val):
+        self.qt_progress_bar.setRange(min_val, max_val)
 
     def setValue(self, value):
         self.qt_progress_bar.setValue(value)
@@ -74,8 +93,10 @@ class QtLabeledProgressBar(QWidget):
     def _set_total(self, event):
         self.setRange(0, event.value)
 
-    def _close(self, event):
-        super().close()
+    def _cancel(self):
+        self.cancel_button.setText(trans._('Cancelling...'))
+        self.progress.cancel()
+        self.cancel_button.setText(trans._('Canceled'))
 
 
 class QtProgressBarGroup(QWidget):
@@ -87,7 +108,7 @@ class QtProgressBarGroup(QWidget):
         parent: Optional[QWidget] = None,
     ) -> None:
         super().__init__(parent)
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setAttribute(QtCore.Qt.WidgetAttribute.WA_DeleteOnClose)
 
         pbr_group_layout = QVBoxLayout()
         pbr_group_layout.addWidget(qt_progress_bar)
