@@ -13,17 +13,16 @@ from qtpy.QtWidgets import (
     QVBoxLayout,
 )
 
-from ...utils.action_manager import action_manager
-from ...utils.interactions import Shortcut
-from ...utils.misc import in_ipython
-from ...utils.translations import trans
-from ..dialogs.qt_modal import QtPopup
-from .qt_dims_sorter import QtDimsSorter
-from .qt_spinbox import QtSpinBox
-from .qt_tooltip import QtToolTipLabel
+from napari._qt.dialogs.qt_modal import QtPopup
+from napari._qt.widgets.qt_dims_sorter import QtDimsSorter
+from napari._qt.widgets.qt_spinbox import QtSpinBox
+from napari._qt.widgets.qt_tooltip import QtToolTipLabel
+from napari.utils.action_manager import action_manager
+from napari.utils.misc import in_ipython, in_jupyter, in_python_repl
+from napari.utils.translations import trans
 
 if TYPE_CHECKING:
-    from ...viewer import Viewer
+    from napari.viewer import ViewerModel
 
 
 class QtLayerButtons(QFrame):
@@ -48,11 +47,15 @@ class QtLayerButtons(QFrame):
         Napari viewer containing the rendered scene, layers, and controls.
     """
 
-    def __init__(self, viewer: 'Viewer'):
+    def __init__(self, viewer: 'ViewerModel') -> None:
         super().__init__()
 
         self.viewer = viewer
-        self.deleteButton = QtDeleteButton(self.viewer)
+
+        self.deleteButton = QtViewerPushButton(
+            'delete_button', action='napari:delete_selected_layers'
+        )
+
         self.newPointsButton = QtViewerPushButton(
             'new_points',
             trans._('New points layer'),
@@ -112,7 +115,7 @@ class QtViewerButtons(QFrame):
         Napari viewer containing the rendered scene, layers, and controls.
     """
 
-    def __init__(self, viewer: 'Viewer'):
+    def __init__(self, viewer: 'ViewerModel') -> None:
         super().__init__()
 
         self.viewer = viewer
@@ -121,12 +124,12 @@ class QtViewerButtons(QFrame):
             'console', action='napari:toggle_console_visibility'
         )
         self.consoleButton.setProperty('expanded', False)
-        if in_ipython():
+        if in_ipython() or in_jupyter() or in_python_repl():
             self.consoleButton.setEnabled(False)
 
         rdb = QtViewerPushButton('roll', action='napari:roll_axes')
         self.rollDimsButton = rdb
-        rdb.setContextMenuPolicy(Qt.CustomContextMenu)
+        rdb.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         rdb.customContextMenuRequested.connect(self._open_roll_popup)
 
         self.transposeDimsButton = QtViewerPushButton(
@@ -141,7 +144,7 @@ class QtViewerButtons(QFrame):
         self.gridViewButton = gvb
         gvb.setCheckable(True)
         gvb.setChecked(viewer.grid.enabled)
-        gvb.setContextMenuPolicy(Qt.CustomContextMenu)
+        gvb.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         gvb.customContextMenuRequested.connect(self._open_grid_popup)
 
         @self.viewer.grid.events.enabled.connect
@@ -154,7 +157,7 @@ class QtViewerButtons(QFrame):
         self.ndisplayButton = ndb
         ndb.setCheckable(True)
         ndb.setChecked(self.viewer.dims.ndisplay == 3)
-        ndb.setContextMenuPolicy(Qt.CustomContextMenu)
+        ndb.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         ndb.customContextMenuRequested.connect(self.open_perspective_popup)
 
         @self.viewer.dims.events.ndisplay.connect
@@ -178,12 +181,13 @@ class QtViewerButtons(QFrame):
             return
 
         # make slider connected to perspective parameter
-        sld = QSlider(Qt.Horizontal, self)
-        sld.setRange(0, max(90, self.viewer.camera.perspective))
-        sld.setValue(self.viewer.camera.perspective)
+        sld = QSlider(Qt.Orientation.Horizontal, self)
+        sld.setRange(0, max(90, int(self.viewer.camera.perspective)))
+        sld.setValue(int(self.viewer.camera.perspective))
         sld.valueChanged.connect(
             lambda v: setattr(self.viewer.camera, 'perspective', v)
         )
+        self.perspective_slider = sld
 
         # make layout
         layout = QHBoxLayout()
@@ -237,7 +241,7 @@ class QtViewerButtons(QFrame):
         stride_max = self.viewer.grid.__fields__['stride'].type_.le
         stride_not = self.viewer.grid.__fields__['stride'].type_.ne
         grid_stride.setObjectName("gridStrideBox")
-        grid_stride.setAlignment(Qt.AlignCenter)
+        grid_stride.setAlignment(Qt.AlignmentFlag.AlignCenter)
         grid_stride.setRange(stride_min, stride_max)
         grid_stride.setProhibitValue(stride_not)
         grid_stride.setValue(self.viewer.grid.stride)
@@ -247,7 +251,7 @@ class QtViewerButtons(QFrame):
         width_min = self.viewer.grid.__fields__['shape'].sub_fields[1].type_.ge
         width_not = self.viewer.grid.__fields__['shape'].sub_fields[1].type_.ne
         grid_width.setObjectName("gridWidthBox")
-        grid_width.setAlignment(Qt.AlignCenter)
+        grid_width.setAlignment(Qt.AlignmentFlag.AlignCenter)
         grid_width.setMinimum(width_min)
         grid_width.setProhibitValue(width_not)
         grid_width.setValue(self.viewer.grid.shape[1])
@@ -261,7 +265,7 @@ class QtViewerButtons(QFrame):
             self.viewer.grid.__fields__['shape'].sub_fields[0].type_.ne
         )
         grid_height.setObjectName("gridStrideBox")
-        grid_height.setAlignment(Qt.AlignCenter)
+        grid_height.setAlignment(Qt.AlignmentFlag.AlignCenter)
         grid_height.setMinimum(height_min)
         grid_height.setProhibitValue(height_not)
         grid_height.setValue(self.viewer.grid.shape[0])
@@ -337,87 +341,13 @@ class QtViewerButtons(QFrame):
         self.viewer.grid.shape = (value, self.viewer.grid.shape[1])
 
 
-class QtDeleteButton(QPushButton):
-    """Delete button to remove selected layers.
-
-    Parameters
-    ----------
-    viewer : napari.components.ViewerModel
-        Napari viewer containing the rendered scene, layers, and controls.
-
-    Attributes
-    ----------
-    hover : bool
-        Hover is true while mouse cursor is on the button widget.
-    viewer : napari.components.ViewerModel
-        Napari viewer containing the rendered scene, layers, and controls.
-    """
-
-    def __init__(self, viewer):
-        super().__init__()
-
-        self.viewer = viewer
-        self.setToolTip(
-            trans._(
-                "Delete selected layers ({shortcut})",
-                shortcut=Shortcut("Control-Backspace"),
-            )
-        )
-        self.setAcceptDrops(True)
-        self.clicked.connect(lambda: self.viewer.layers.remove_selected())
-
-    def dragEnterEvent(self, event):
-        """The cursor enters the widget during a drag and drop operation.
-
-        Parameters
-        ----------
-        event : qtpy.QtCore.QEvent
-            Event from the Qt context.
-        """
-        event.accept()
-        self.hover = True
-        self.update()
-
-    def dragLeaveEvent(self, event):
-        """The cursor leaves the widget during a drag and drop operation.
-
-        Using event.ignore() here allows the event to pass through the
-        parent widget to its child widget, otherwise the parent widget
-        would catch the event and not pass it on to the child widget.
-
-        Parameters
-        ----------
-        event : qtpy.QtCore.QEvent
-            Event from the Qt context.
-        """
-        event.ignore()
-        self.hover = False
-        self.update()
-
-    def dropEvent(self, event):
-        """The drag and drop mouse event is completed.
-
-        Parameters
-        ----------
-        event : qtpy.QtCore.QEvent
-            Event from the Qt context.
-        """
-        event.accept()
-        layer_name = event.mimeData().text()
-        layer = self.viewer.layers[layer_name]
-        if not layer.selected:
-            self.viewer.layers.remove(layer)
-        else:
-            self.viewer.layers.remove_selected()
-
-
 def _omit_viewer_args(constructor):
     @wraps(constructor)
     def _func(*args, **kwargs):
         if len(args) > 1 and not isinstance(args[1], str):
             warnings.warn(
                 trans._(
-                    "viewer argument is deprecated and should not be used"
+                    "viewer argument is deprecated since 0.4.14 and should not be used"
                 ),
                 category=FutureWarning,
                 stacklevel=2,
@@ -426,7 +356,7 @@ def _omit_viewer_args(constructor):
         if "viewer" in kwargs:
             warnings.warn(
                 trans._(
-                    "viewer argument is deprecated and should not be used"
+                    "viewer argument is deprecated since 0.4.14 and should not be used"
                 ),
                 category=FutureWarning,
                 stacklevel=2,
@@ -450,17 +380,12 @@ class QtViewerPushButton(QPushButton):
         callable to be triggered on button click
     action : str
         action name to be triggered on button click
-
-    Attributes
-    ----------
-    viewer : napari.components.ViewerModel
-        Napari viewer containing the rendered scene, layers, and controls.
     """
 
     @_omit_viewer_args
     def __init__(
         self, button_name: str, tooltip: str = '', slot=None, action: str = ''
-    ):
+    ) -> None:
         super().__init__()
 
         self.setToolTip(tooltip or button_name)
@@ -522,10 +447,7 @@ class QtStateButton(QtViewerPushButton):
 
     def change(self):
         """Toggle between the multiple states of this button."""
-        if self.isChecked():
-            newstate = self._onstate
-        else:
-            newstate = self._offstate
+        newstate = self._onstate if self.isChecked() else self._offstate
         setattr(self._target, self._attribute, newstate)
 
     def _on_change(self, event=None):
