@@ -3,13 +3,16 @@ from unittest.mock import Mock
 
 import numpy as np
 
+from napari._tests.utils import skip_on_win_ci
+from napari.layers.base._base_mouse_bindings import InteractionBoxHandle
 
-def test_viewer_mouse_bindings(make_test_viewer):
-    """Test adding mouse bindings to the viewer
-    """
+
+@skip_on_win_ci
+def test_viewer_mouse_bindings(make_napari_viewer):
+    """Test adding mouse bindings to the viewer"""
     np.random.seed(0)
-    viewer = make_test_viewer()
-    view = viewer.window.qt_viewer
+    viewer = make_napari_viewer()
+    view = viewer.window._qt_viewer
 
     if os.getenv("CI"):
         viewer.show()
@@ -78,18 +81,18 @@ def test_viewer_mouse_bindings(make_test_viewer):
     mock_move.method.assert_not_called()
 
 
-def test_layer_mouse_bindings(make_test_viewer):
-    """Test adding mouse bindings to a layer that is selected
-    """
+@skip_on_win_ci
+def test_layer_mouse_bindings(make_napari_viewer):
+    """Test adding mouse bindings to a layer that is selected"""
     np.random.seed(0)
-    viewer = make_test_viewer()
-    view = viewer.window.qt_viewer
+    viewer = make_napari_viewer()
+    view = viewer.window._qt_viewer
 
     if os.getenv("CI"):
         viewer.show()
 
     layer = viewer.add_image(np.random.random((10, 20)))
-    layer.selected = True
+    viewer.layers.selection.add(layer)
 
     mock_press = Mock()
     mock_drag = Mock()
@@ -152,20 +155,38 @@ def test_layer_mouse_bindings(make_test_viewer):
     mock_drag.method.assert_called_once()
     mock_release.method.assert_called_once()
     mock_move.method.assert_not_called()
+    mock_press.reset_mock()
+    mock_drag.reset_mock()
+    mock_release.reset_mock()
+
+    # simulate hover in transform mode
+    layer.mode = 'transform'
+    # go to middle of the canvas, so we're sure to be inside
+    position = tuple(d // 2 for d in view.canvas.size)
+    view.canvas.events.mouse_move(pos=position, modifiers=())
+    mock_press.method.assert_not_called()
+    mock_drag.method.assert_not_called()
+    mock_release.method.assert_not_called()
+    mock_move.method.assert_called_once()
+    assert (
+        layer._overlays['transform_box'].selected_handle
+        == InteractionBoxHandle.INSIDE
+    )
+    mock_move.reset_mock()
 
 
-def test_unselected_layer_mouse_bindings(make_test_viewer):
-    """Test adding mouse bindings to a layer that is not selected
-    """
+@skip_on_win_ci
+def test_unselected_layer_mouse_bindings(make_napari_viewer):
+    """Test adding mouse bindings to a layer that is not selected"""
     np.random.seed(0)
-    viewer = make_test_viewer()
-    view = viewer.window.qt_viewer
+    viewer = make_napari_viewer()
+    view = viewer.window._qt_viewer
 
     if os.getenv("CI"):
         viewer.show()
 
     layer = viewer.add_image(np.random.random((10, 20)))
-    layer.selected = False
+    viewer.layers.selection.remove(layer)
 
     mock_press = Mock()
     mock_drag = Mock()
