@@ -1,6 +1,6 @@
 import random
 
-from .cache import Cache
+from napari._vendor.experimental.cachetools.cachetools.cache import Cache
 
 
 # random.choice cannot be pickled in Python 2.7
