@@ -2,19 +2,21 @@ from functools import partial
 from typing import Dict, List, Optional, TYPE_CHECKING, Tuple
 
 from qtpy import QtCore, QtGui, QtWidgets
-from ...._qt.widgets.qt_highlight_preview import QtHighlightSizePreviewWidget
-from ...._qt.widgets.qt_keyboard_settings import ShortcutEditor
 
-from .signal import Signal
-from .utils import is_concrete_schema, iter_layout_widgets, state_property
+from napari._qt.widgets.qt_extension2reader import Extension2ReaderTable
+from napari._qt.widgets.qt_highlight_preview import QtHighlightSizePreviewWidget
+from napari._qt.widgets.qt_keyboard_settings import ShortcutEditor
 
-from ...._qt.widgets.qt_plugin_sorter import QtPluginSorter
+from napari._vendor.qt_json_builder.qt_jsonschema_form.signal import Signal
+from napari._vendor.qt_json_builder.qt_jsonschema_form.utils import is_concrete_schema, iter_layout_widgets, state_property
 
-from ...._qt.widgets.qt_spinbox import QtSpinBox
+from napari._qt.widgets.qt_plugin_sorter import QtPluginSorter
+
+from napari._qt.widgets.qt_spinbox import QtSpinBox
 
 
 if TYPE_CHECKING:
-    from .form import WidgetBuilder
+    from napari._vendor.qt_json_builder.qt_jsonschema_form.form import WidgetBuilder
 
 
 class SchemaWidgetMixin:
@@ -151,6 +153,11 @@ class SpinDoubleSchemaWidget(SchemaWidgetMixin, QtWidgets.QDoubleSpinBox):
         self.opacity = QtWidgets.QGraphicsOpacityEffect(self)
         self.setGraphicsEffect(self.opacity)
         self.opacity.setOpacity(1)
+        if 'minimum' in self.schema:
+            self.setMinimum(self.schema['minimum'])
+        if 'maximum' in self.schema:
+            self.setMaximum(self.schema['maximum'])
+
 
     def setDescription(self, description: str):
         self.description = description
@@ -618,7 +625,26 @@ class ShortcutsWidget(SchemaWidgetMixin, ShortcutEditor):
         self.opacity.setOpacity(1)
 
 
-class ObjectSchemaWidget(SchemaWidgetMixin, QtWidgets.QGroupBox):
+class Extension2ReaderWidget(SchemaWidgetMixin, Extension2ReaderTable):
+    @state_property
+    def state(self) -> dict:
+        return self.value()
+
+    def setDescription(self, description: str):
+        self.description = description
+
+    @state.setter
+    def state(self, state: dict):
+        # self.setValue(state)
+        return None
+
+    def configure(self):
+        self.valueChanged.connect(self.on_changed.emit)
+        self.opacity = QtWidgets.QGraphicsOpacityEffect(self)
+        self.setGraphicsEffect(self.opacity)
+        self.opacity.setOpacity(1)
+
+class ObjectSchemaWidgetMinix(SchemaWidgetMixin):
     def __init__(
         self,
         schema: dict,
@@ -651,6 +677,50 @@ class ObjectSchemaWidget(SchemaWidgetMixin, QtWidgets.QGroupBox):
     def setDescription(self, description: str):
         self.description = description
 
+    def populate_from_schema(
+        self,
+        schema: dict,
+        ui_schema: dict,
+        widget_builder: 'WidgetBuilder',
+    ) -> Dict[str, QtWidgets.QWidget]:
+        raise NotImplementedError
+
+    def _prepare_widget(self, name: str, sub_schema: dict, widget_builder: 'WidgetBuilder', ui_schema: dict):
+        description = sub_schema.get('description', "")
+
+        label = QtWidgets.QLabel(sub_schema.get("title", name))
+
+        sub_ui_schema = ui_schema.get(name, {})
+        widget = widget_builder.create_widget(
+            sub_schema, sub_ui_schema, description=description
+        )  # TODO on changed
+        widget._name = name
+        widget.on_changed.connect(partial(self.widget_on_changed, name))
+
+        return label, widget
+
+class HorizontalObjectSchemaWidget(ObjectSchemaWidgetMinix, QtWidgets.QWidget):
+    def populate_from_schema(
+        self,
+        schema: dict,
+        ui_schema: dict,
+        widget_builder: 'WidgetBuilder',
+    ) -> Dict[str, QtWidgets.QWidget]:
+        layout = QtWidgets.QHBoxLayout()
+        self.setLayout(layout)
+
+        widgets = {}
+        for name, sub_schema in schema['properties'].items():
+            label, widget = self._prepare_widget(name, sub_schema, widget_builder, ui_schema)
+            layout.addWidget(label)
+            layout.addWidget(widget)
+            widgets[name] = widget
+
+        return widgets
+
+
+class ObjectSchemaWidget(ObjectSchemaWidgetMinix, QtWidgets.QGroupBox):
+
     def populate_from_schema(
         self,
         schema: dict,
@@ -665,26 +735,16 @@ class ObjectSchemaWidget(SchemaWidgetMixin, QtWidgets.QGroupBox):
         if 'title' in schema:
             self.setTitle(schema['title'])
 
-        if 'description' in schema:
-            self.setToolTip(schema['description'])
 
         # Populate rows
         widgets = {}
         layout.setFieldGrowthPolicy(QtWidgets.QFormLayout.FieldGrowthPolicy(1))
         for name, sub_schema in schema['properties'].items():
-            if 'description' in sub_schema:
-                description = sub_schema['description']
+            label, widget = self._prepare_widget(name, sub_schema, widget_builder, ui_schema)
+            if len(schema['properties']) == 1:
+                layout.addRow(widget)
             else:
-                description = ""
-
-            sub_ui_schema = ui_schema.get(name, {})
-            widget = widget_builder.create_widget(
-                sub_schema, sub_ui_schema, description=description
-            )  # TODO onchanged
-            widget._name = name
-            widget.on_changed.connect(partial(self.widget_on_changed, name))
-            label = sub_schema.get("title", name)
-            layout.addRow(label, widget)
+                layout.addRow(label, widget)
             widgets[name] = widget
 
         return widgets
@@ -697,6 +757,7 @@ class EnumSchemaWidget(SchemaWidgetMixin, QtWidgets.QComboBox):
 
     @state.setter
     def state(self, value):
+        value = str(value)
         index = self.findData(value)
         if index == -1:
             raise ValueError(value)
