@@ -14,6 +14,7 @@ def test_image_rendering(make_napari_viewer):
 
     data = np.random.random((20, 20, 20))
     layer = viewer.add_image(data)
+    vispy_layer = viewer.window._qt_viewer.layer_to_visual[layer]
 
     assert layer.rendering == 'mip'
 
@@ -45,6 +46,13 @@ def test_image_rendering(make_napari_viewer):
     layer.rendering = 'additive'
     assert layer.rendering == 'additive'
 
+    # check custom interpolation works on the 2D node
+    with pytest.raises(NotImplementedError):
+        layer.interpolation3d = 'custom'
+    viewer.dims.ndisplay = 2
+    layer.interpolation2d = 'custom'
+    assert vispy_layer.node.interpolation == 'custom'
+
 
 @skip_on_win_ci
 def test_visibility_consistency(qapp, make_napari_viewer):
@@ -80,7 +88,6 @@ def test_clipping_planes_dims():
     vispy_layer = VispyImageLayer(image_layer)
     napari_clip = image_layer.experimental_clipping_planes.as_array()
     # needed to get volume node
-    image_layer._ndisplay = 3
-    vispy_layer._on_display_change()
+    image_layer._slice_dims(ndisplay=3)
     vispy_clip = vispy_layer.node.clipping_planes
     assert np.all(napari_clip == vispy_clip[..., ::-1])
