@@ -38,7 +38,7 @@ def test_change_text_updates_node_string():
 def test_change_text_color_updates_node_color():
     shapes = np.random.rand(3, 4, 2)
     properties = {'class': np.array(['A', 'B', 'C'])}
-    text = {'text': 'class', 'color': [1, 0, 0]}
+    text = {'string': 'class', 'color': [1, 0, 0]}
     layer = Shapes(shapes, properties=properties, text=text)
     vispy_layer = VispyShapesLayer(layer)
     text_node = vispy_layer._get_text_node()
@@ -74,3 +74,16 @@ def test_update_property_value_then_refresh_text_updates_node_strings():
     layer.refresh_text()
 
     np.testing.assert_array_equal(text_node.text, ['A', 'D', 'C'])
+
+
+def test_text_with_non_empty_constant_string():
+    shapes = np.random.rand(3, 4, 2)
+    layer = Shapes(shapes, text={'string': {'constant': 'a'}})
+
+    vispy_layer = VispyShapesLayer(layer)
+
+    text_node = vispy_layer._get_text_node()
+    # Vispy cannot broadcast a constant string and assert_array_equal
+    # automatically broadcasts, so explicitly check length.
+    assert len(text_node.text) == 3
+    np.testing.assert_array_equal(text_node.text, ['a', 'a', 'a'])
