@@ -87,9 +87,9 @@ class TracksFilter(Filter):
 
     def __init__(
         self,
-        current_time: Union[int, float] = 0,
-        tail_length: Union[int, float] = 30,
-        head_length: Union[int, float] = 0,
+        current_time: float = 0,
+        tail_length: float = 30,
+        head_length: float = 0,
         use_fade: bool = True,
         vertex_time: Union[List, np.ndarray] = None,
     ) -> None:
@@ -104,11 +104,11 @@ class TracksFilter(Filter):
         self.vertex_time = vertex_time
 
     @property
-    def current_time(self) -> Union[int, float]:
+    def current_time(self) -> float:
         return self._current_time
 
     @current_time.setter
-    def current_time(self, n: Union[int, float]):
+    def current_time(self, n: float):
         self._current_time = n
         if isinstance(n, slice):
             n = np.max(self._vertex_time)
@@ -124,20 +124,20 @@ class TracksFilter(Filter):
         self.vshader['use_fade'] = float(self._use_fade)
 
     @property
-    def tail_length(self) -> Union[int, float]:
+    def tail_length(self) -> float:
         return self._tail_length
 
     @tail_length.setter
-    def tail_length(self, tail_length: Union[int, float]):
+    def tail_length(self, tail_length: float):
         self._tail_length = tail_length
         self.vshader['tail_length'] = float(self._tail_length)
 
     @property
-    def head_length(self) -> Union[int, float]:
+    def head_length(self) -> float:
         return self._tail_length
 
     @head_length.setter
-    def head_length(self, head_length: Union[int, float]):
+    def head_length(self, head_length: float):
         self._head_length = head_length
         self.vshader['head_length'] = float(self._head_length)
 
