@@ -6,6 +6,7 @@ from vispy.visuals.transforms import MatrixTransform
 from napari._vispy.utils.gl import BLENDING_MODES, get_max_texture_sizes
 from napari.components.overlays.base import CanvasOverlay, SceneOverlay
 from napari.utils.events import disconnect_events
+from napari.utils.transforms import Affine
 
 
 class VispyBaseLayer(ABC):
@@ -216,6 +217,42 @@ class VispyBaseLayer(ABC):
             affine_matrix = affine_matrix @ affine_offset
         self._master_transform.matrix = affine_matrix
 
+        # Because of performance reason, for multiscale images
+        # we load only visible part of data to GPU.
+        # To place this part of data correctly we update transform,
+        # but this leads to incorrect placement of child layers.
+        # To fix this we need to update child layers transform.
+        dims_displayed = self.layer._slice_input.displayed
+        simplified_transform = self.layer._transforms.simplified
+        if simplified_transform is None:
+            raise ValueError(
+                "simplified transform is None"
+            )  # pragma: no cover
+        translate_child = (
+            self.layer.translate[dims_displayed]
+            + self.layer.affine.translate[dims_displayed]
+        )[::-1]
+        if self.layer.affine.ndim > len(dims_displayed):
+            aff = Affine(
+                linear_matrix=simplified_transform.linear_matrix[
+                    np.ix_(dims_displayed, dims_displayed)
+                ]
+            )
+            trans_rotate = aff.rotate
+            trans_scale = aff.scale[::-1]
+        else:
+            trans_rotate = simplified_transform.rotate[
+                np.ix_(dims_displayed, dims_displayed)
+            ]
+            trans_scale = simplified_transform.scale[dims_displayed][::-1]
+        new_translate = (
+            np.dot(trans_rotate, (translate_child - translate)) / trans_scale
+        )
+        child_matrix = np.eye(4)
+        child_matrix[-1, : len(translate)] = new_translate
+        for child in self.node.children:
+            child.transform.matrix = child_matrix
+
     def _on_experimental_clipping_planes_change(self):
         if hasattr(self.node, 'clipping_planes') and hasattr(
             self.layer, 'experimental_clipping_planes'
