@@ -1,14 +1,19 @@
+from __future__ import annotations
+
 import warnings
+from typing import Dict, Optional
 
 import numpy as np
 from vispy.color import Colormap as VispyColormap
 from vispy.scene.node import Node
+from vispy.visuals import ImageVisual
 
 from napari._vispy.layers.base import VispyBaseLayer
 from napari._vispy.utils.gl import fix_data_dtype, get_gl_extensions
 from napari._vispy.visuals.image import Image as ImageNode
 from napari._vispy.visuals.volume import Volume as VolumeNode
 from napari.layers.base._base_constants import Blending
+from napari.layers.image.image import Image, _ImageBase
 from napari.utils.translations import trans
 
 
@@ -25,7 +30,9 @@ class ImageLayerNode:
 
         self._custom_node = custom_node
         self._image_node = ImageNode(
-            None,
+            None
+            if (texture_format is None or texture_format == 'auto')
+            else np.array([[0.0]], dtype=np.float32),
             method='auto',
             texture_format=texture_format,
         )
@@ -35,21 +42,45 @@ class ImageLayerNode:
             texture_format=texture_format,
         )
 
-    def get_node(self, ndisplay: int) -> Node:
+    def get_node(
+        self, ndisplay: int, dtype: Optional[np.dtype] = None
+    ) -> Node:
         # Return custom node if we have one.
         if self._custom_node is not None:
             return self._custom_node
 
         # Return Image or Volume node based on 2D or 3D.
-        if ndisplay == 2:
-            return self._image_node
-        return self._volume_node
+        res = self._image_node if ndisplay == 2 else self._volume_node
+        if (
+            res.texture_format not in {"auto", None}
+            and dtype is not None
+            and _VISPY_FORMAT_TO_DTYPE[res.texture_format] != dtype
+        ):
+            # it is a bug to hit this error — it is here to catch bugs
+            # early when we are creating the wrong nodes or
+            # textures for our data
+            raise ValueError(
+                trans._(
+                    "dtype {dtype} does not match texture_format={texture_format}",
+                    dtype=dtype,
+                    texture_format=res.texture_format,
+                )
+            )
+        return res
 
 
-class VispyImageLayer(VispyBaseLayer):
-    def __init__(self, layer, node=None, texture_format='auto') -> None:
+class VispyScalarFieldBaseLayer(VispyBaseLayer):
+    def __init__(
+        self,
+        layer: _ImageBase,
+        node=None,
+        texture_format='auto',
+        layer_node_class=ImageLayerNode,
+    ) -> None:
         # Use custom node from caller, or our standard image/volume nodes.
-        self._layer_node = ImageLayerNode(node, texture_format=texture_format)
+        self._layer_node = layer_node_class(
+            node, texture_format=texture_format
+        )
 
         # Default to 2D (image) node.
         super().__init__(layer, self._layer_node.get_node(2))
@@ -58,19 +89,7 @@ class VispyImageLayer(VispyBaseLayer):
 
         self.layer.events.rendering.connect(self._on_rendering_change)
         self.layer.events.depiction.connect(self._on_depiction_change)
-        self.layer.events.interpolation2d.connect(
-            self._on_interpolation_change
-        )
-        self.layer.events.interpolation3d.connect(
-            self._on_interpolation_change
-        )
         self.layer.events.colormap.connect(self._on_colormap_change)
-        self.layer.events.contrast_limits.connect(
-            self._on_contrast_limits_change
-        )
-        self.layer.events.gamma.connect(self._on_gamma_change)
-        self.layer.events.iso_threshold.connect(self._on_iso_threshold_change)
-        self.layer.events.attenuation.connect(self._on_attenuation_change)
         self.layer.plane.events.position.connect(
             self._on_plane_position_change
         )
@@ -82,9 +101,10 @@ class VispyImageLayer(VispyBaseLayer):
             self._on_custom_interpolation_kernel_2d_change
         )
 
-        # display_change is special (like data_change) because it requires a self.reset()
-        # this means that we have to call it manually. Also, it must be called before reset
-        # in order to set the appropriate node first
+        # display_change is special (like data_change) because it requires a
+        # self.reset(). This means that we have to call it manually. Also,
+        # it must be called before reset in order to set the appropriate node
+        # first
         self._on_display_change()
         self.reset()
         self._on_data_change()
@@ -93,10 +113,16 @@ class VispyImageLayer(VispyBaseLayer):
         parent = self.node.parent
         self.node.parent = None
         ndisplay = self.layer._slice_input.ndisplay
-        self.node = self._layer_node.get_node(ndisplay)
+        self.node = self._layer_node.get_node(
+            ndisplay, getattr(data, "dtype", None)
+        )
 
         if data is None:
-            data = np.zeros((1,) * ndisplay, dtype=np.float32)
+            texture_format = self.node.texture_format
+            data = np.zeros(
+                (1,) * ndisplay,
+                dtype=get_dtype_from_vispy_texture_format(texture_format),
+            )
 
         if self.layer._empty:
             self.node.visible = False
@@ -126,6 +152,10 @@ class VispyImageLayer(VispyBaseLayer):
         data = fix_data_dtype(data)
         ndisplay = self.layer._slice_input.ndisplay
 
+        node = self._layer_node.get_node(
+            ndisplay, getattr(data, "dtype", None)
+        )
+
         if ndisplay == 3 and self.layer.ndim == 2:
             data = np.expand_dims(data, axis=0)
 
@@ -137,7 +167,9 @@ class VispyImageLayer(VispyBaseLayer):
 
         # Check if ndisplay has changed current node type needs updating
         if (ndisplay == 3 and not isinstance(node, VolumeNode)) or (
-            ndisplay == 2 and not isinstance(node, ImageNode)
+            ndisplay == 2
+            and not isinstance(node, ImageVisual)
+            or node != self.node
         ):
             self._on_display_change(data)
         else:
@@ -152,13 +184,6 @@ class VispyImageLayer(VispyBaseLayer):
         self._on_matrix_change()
         node.update()
 
-    def _on_interpolation_change(self):
-        self.node.interpolation = (
-            self.layer.interpolation2d
-            if self.layer._slice_input.ndisplay == 2
-            else self.layer.interpolation3d
-        )
-
     def _on_custom_interpolation_kernel_2d_change(self):
         if self.layer._slice_input.ndisplay == 2:
             self.node.custom_kernel = self.layer.custom_interpolation_kernel_2d
@@ -166,59 +191,13 @@ class VispyImageLayer(VispyBaseLayer):
     def _on_rendering_change(self):
         if isinstance(self.node, VolumeNode):
             self.node.method = self.layer.rendering
-            self._on_attenuation_change()
-            self._on_iso_threshold_change()
 
     def _on_depiction_change(self):
         if isinstance(self.node, VolumeNode):
             self.node.raycasting_mode = str(self.layer.depiction)
 
-    def _on_colormap_change(self):
-        self.node.cmap = VispyColormap(*self.layer.colormap)
-
-    def _update_mip_minip_cutoff(self):
-        # discard fragments beyond contrast limits, but only with translucent blending
-        if isinstance(self.node, VolumeNode):
-            if self.layer.blending in {
-                Blending.TRANSLUCENT,
-                Blending.TRANSLUCENT_NO_DEPTH,
-            }:
-                self.node.mip_cutoff = self.node._texture.clim_normalized[0]
-                self.node.minip_cutoff = self.node._texture.clim_normalized[1]
-            else:
-                self.node.mip_cutoff = None
-                self.node.minip_cutoff = None
-
-    def _on_contrast_limits_change(self):
-        self.node.clim = self.layer.contrast_limits
-        # cutoffs must be updated after clims, so we can set them to the new values
-        self._update_mip_minip_cutoff()
-        # iso also may depend on contrast limit values
-        self._on_iso_threshold_change()
-
     def _on_blending_change(self):
         super()._on_blending_change()
-        # cutoffs must be updated after blending, so we can know if
-        # the new blending is a translucent one
-        self._update_mip_minip_cutoff()
-
-    def _on_gamma_change(self):
-        if len(self.node.shared_program.frag._set_items) > 0:
-            self.node.gamma = self.layer.gamma
-
-    def _on_iso_threshold_change(self):
-        if isinstance(self.node, VolumeNode):
-            if self.node._texture.is_normalized:
-                cmin, cmax = self.layer.contrast_limits_range
-                self.node.threshold = (self.layer.iso_threshold - cmin) / (
-                    cmax - cmin
-                )
-            else:
-                self.node.threshold = self.layer.iso_threshold
-
-    def _on_attenuation_change(self):
-        if isinstance(self.node, VolumeNode):
-            self.node.attenuation = self.layer.attenuation
 
     def _on_plane_thickness_change(self):
         if isinstance(self.node, VolumeNode):
@@ -234,10 +213,6 @@ class VispyImageLayer(VispyBaseLayer):
 
     def reset(self, event=None):
         super().reset()
-        self._on_interpolation_change()
-        self._on_colormap_change()
-        self._on_contrast_limits_change()
-        self._on_gamma_change()
         self._on_rendering_change()
         self._on_depiction_change()
         self._on_plane_position_change()
@@ -264,7 +239,9 @@ class VispyImageLayer(VispyBaseLayer):
             if self.layer.multiscale:
                 raise ValueError(
                     trans._(
-                        "Shape of in dividual tiles in multiscale {shape} cannot exceed GL_MAX_TEXTURE_SIZE {texture_size}. Rendering is currently in {ndisplay}D mode.",
+                        "Shape of individual tiles in multiscale {shape} cannot "
+                        "exceed GL_MAX_TEXTURE_SIZE {texture_size}. Rendering is "
+                        "currently in {ndisplay}D mode.",
                         deferred=True,
                         shape=data.shape,
                         texture_size=MAX_TEXTURE_SIZE,
@@ -273,7 +250,9 @@ class VispyImageLayer(VispyBaseLayer):
                 )
             warnings.warn(
                 trans._(
-                    "data shape {shape} exceeds GL_MAX_TEXTURE_SIZE {texture_size} in at least one axis and will be downsampled. Rendering is currently in {ndisplay}D mode.",
+                    "data shape {shape} exceeds GL_MAX_TEXTURE_SIZE {texture_size}"
+                    " in at least one axis and will be downsampled."
+                    " Rendering is currently in {ndisplay}D mode.",
                     deferred=True,
                     shape=data.shape,
                     texture_size=MAX_TEXTURE_SIZE,
@@ -291,3 +270,137 @@ class VispyImageLayer(VispyBaseLayer):
             slices = tuple(slice(None, None, ds) for ds in downsample)
             data = data[slices]
         return data
+
+
+class VispyImageLayer(VispyScalarFieldBaseLayer):
+    layer: Image
+
+    def __init__(
+        self,
+        layer: Image,
+        node=None,
+        texture_format='auto',
+        layer_node_class=ImageLayerNode,
+    ) -> None:
+        super().__init__(
+            layer,
+            node=node,
+            texture_format=texture_format,
+            layer_node_class=layer_node_class,
+        )
+
+        self.layer.events.interpolation2d.connect(
+            self._on_interpolation_change
+        )
+        self.layer.events.interpolation3d.connect(
+            self._on_interpolation_change
+        )
+        self.layer.events.contrast_limits.connect(
+            self._on_contrast_limits_change
+        )
+        self.layer.events.gamma.connect(self._on_gamma_change)
+        self.layer.events.iso_threshold.connect(self._on_iso_threshold_change)
+        self.layer.events.attenuation.connect(self._on_attenuation_change)
+
+        # display_change is special (like data_change) because it requires a
+        # self.reset(). This means that we have to call it manually. Also,
+        # it must be called before reset in order to set the appropriate node
+        # first
+        self._on_display_change()
+        self.reset()
+        self._on_data_change()
+
+    def _on_interpolation_change(self) -> None:
+        self.node.interpolation = (
+            self.layer.interpolation2d
+            if self.layer._slice_input.ndisplay == 2
+            else self.layer.interpolation3d
+        )
+
+    def _on_rendering_change(self) -> None:
+        super()._on_rendering_change()
+        self._on_attenuation_change()
+        self._on_iso_threshold_change()
+
+    def _on_colormap_change(self, event=None) -> None:
+        self.node.cmap = VispyColormap(*self.layer.colormap)
+
+    def _update_mip_minip_cutoff(self) -> None:
+        # discard fragments beyond contrast limits, but only with translucent blending
+        if isinstance(self.node, VolumeNode):
+            if self.layer.blending in {
+                Blending.TRANSLUCENT,
+                Blending.TRANSLUCENT_NO_DEPTH,
+            }:
+                self.node.mip_cutoff = self.node._texture.clim_normalized[0]
+                self.node.minip_cutoff = self.node._texture.clim_normalized[1]
+            else:
+                self.node.mip_cutoff = None
+                self.node.minip_cutoff = None
+
+    def _on_contrast_limits_change(self) -> None:
+        self.node.clim = self.layer.contrast_limits
+        # cutoffs must be updated after clims, so we can set them to the new values
+        self._update_mip_minip_cutoff()
+        # iso also may depend on contrast limit values
+        self._on_iso_threshold_change()
+
+    def _on_blending_change(self, event=None) -> None:
+        super()._on_blending_change()
+        # cutoffs must be updated after blending, so we can know if
+        # the new blending is a translucent one
+        self._update_mip_minip_cutoff()
+
+    def _on_gamma_change(self) -> None:
+        if len(self.node.shared_program.frag._set_items) > 0:
+            self.node.gamma = self.layer.gamma
+
+    def _on_iso_threshold_change(self) -> None:
+        if isinstance(self.node, VolumeNode):
+            if self.node._texture.is_normalized:
+                cmin, cmax = self.layer.contrast_limits_range
+                self.node.threshold = (self.layer.iso_threshold - cmin) / (
+                    cmax - cmin
+                )
+            else:
+                self.node.threshold = self.layer.iso_threshold
+
+    def _on_attenuation_change(self) -> None:
+        if isinstance(self.node, VolumeNode):
+            self.node.attenuation = self.layer.attenuation
+
+    def reset(self, event=None) -> None:
+        super().reset()
+        self._on_interpolation_change()
+        self._on_colormap_change()
+        self._on_contrast_limits_change()
+        self._on_gamma_change()
+
+
+_VISPY_FORMAT_TO_DTYPE: Dict[Optional[str], np.dtype] = {
+    "r8": np.dtype(np.uint8),
+    "r16": np.dtype(np.uint16),
+    "r32f": np.dtype(np.float32),
+}
+
+_DTYPE_TO_VISPY_FORMAT = {v: k for k, v in _VISPY_FORMAT_TO_DTYPE.items()}
+
+# this is moved after reverse mapping is defined
+# to always have non None values in _DTYPE_TO_VISPY_FORMAT
+_VISPY_FORMAT_TO_DTYPE[None] = np.dtype(np.float32)
+
+
+def get_dtype_from_vispy_texture_format(format_str: str) -> np.dtype:
+    """Get the numpy dtype from a vispy texture format string.
+
+    Parameters
+    ----------
+    format_str : str
+        The vispy texture format string.
+
+    Returns
+    -------
+    dtype : numpy.dtype
+        The numpy dtype corresponding to the vispy texture format string.
+    """
+    return _VISPY_FORMAT_TO_DTYPE.get(format_str, np.dtype(np.float32))
