@@ -1,12 +1,12 @@
 import os
 
+import npe2
 import numpy as np
 import pytest
 
 from napari.components import LayerList
 from napari.layers import Image
-
-BUILTINS = 'napari'
+from napari.layers.utils._link_layers import get_linked_layers
 
 
 def test_empty_layers_list():
@@ -26,9 +26,6 @@ def test_initialize_from_list():
 
 
 def test_adding_layer():
-    """
-    Test adding a Layer
-    """
     layers = LayerList()
     layer = Image(np.random.random((10, 10)))
     layers.append(layer)
@@ -41,9 +38,6 @@ def test_adding_layer():
 
 
 def test_removing_layer():
-    """
-    Test removing a Layer
-    """
     layers = LayerList()
     layer = Image(np.random.random((10, 10)))
     layers.append(layer)
@@ -128,8 +122,9 @@ def test_clearing_layerlist():
     """Test clearing layer list."""
     layers = LayerList()
     layer = Image(np.random.random((10, 10)))
+    layer2 = Image(np.random.random((10, 10)))
     layers.append(layer)
-    layers.append(layer)
+    layers.append(layer2)
     assert len(layers) == 2
 
     layers.clear()
@@ -152,12 +147,31 @@ def test_remove_selected():
     layers.remove_selected()
     assert list(layers) == [layer_a, layer_b]
 
-    # select and remove all layersay
+    # select and remove all layers
     layers.select_all()
     layers.remove_selected()
     assert len(layers) == 0
 
 
+def test_remove_linked_layer():
+    """Test removing a layer that is linked to other layers"""
+    layers = LayerList()
+    layer_a = Image(np.empty((10, 10)))
+    layer_b = Image(np.empty((15, 15)))
+    layer_c = Image(np.empty((15, 15)))
+    layers.extend([layer_a, layer_b, layer_c])
+
+    # link layer_c with layer_b
+    layers.link_layers([layer_c, layer_b])
+    assert len(get_linked_layers(layer_c)) == 1
+    assert len(get_linked_layers(layer_b)) == 1
+
+    layers.selection.add(layer_b)
+    layers.remove_selected()
+    assert len(get_linked_layers(layer_c)) == 0
+
+
+@pytest.mark.filterwarnings('ignore::FutureWarning')
 def test_move_selected():
     """
     Test removing selected layers
@@ -330,7 +344,7 @@ def test_toggle_visibility():
 
 # the layer_data_and_types fixture is defined in napari/conftest.py
 @pytest.mark.filterwarnings('ignore:distutils Version classes are deprecated')
-def test_layers_save(tmpdir, layer_data_and_types):
+def test_layers_save(builtins, tmpdir, layer_data_and_types):
     """Test saving all layer data."""
     list_of_layers, _, _, filenames = layer_data_and_types
     layers = LayerList(list_of_layers)
@@ -341,7 +355,7 @@ def test_layers_save(tmpdir, layer_data_and_types):
     assert not os.path.isdir(path)
 
     # Write data
-    layers.save(path, plugin=BUILTINS)
+    layers.save(path, plugin=builtins.name)
 
     # Check folder now exists
     assert os.path.isdir(path)
@@ -356,7 +370,7 @@ def test_layers_save(tmpdir, layer_data_and_types):
 
 
 # the layer_data_and_types fixture is defined in napari/conftest.py
-def test_layers_save_none_selected(tmpdir, layer_data_and_types):
+def test_layers_save_none_selected(builtins, tmpdir, layer_data_and_types):
     """Test saving all layer data."""
     list_of_layers, _, _, filenames = layer_data_and_types
     layers = LayerList(list_of_layers)
@@ -369,7 +383,7 @@ def test_layers_save_none_selected(tmpdir, layer_data_and_types):
 
     # Write data (will get a warning that nothing is selected)
     with pytest.warns(UserWarning):
-        layers.save(path, selected=True, plugin=BUILTINS)
+        layers.save(path, selected=True, plugin=builtins.name)
 
     # Check folder still does not exist
     assert not os.path.isdir(path)
@@ -383,7 +397,7 @@ def test_layers_save_none_selected(tmpdir, layer_data_and_types):
 
 
 # the layer_data_and_types fixture is defined in napari/conftest.py
-def test_layers_save_selected(tmpdir, layer_data_and_types):
+def test_layers_save_selected(builtins, tmpdir, layer_data_and_types):
     """Test saving all layer data."""
     list_of_layers, _, _, filenames = layer_data_and_types
     layers = LayerList(list_of_layers)
@@ -396,7 +410,7 @@ def test_layers_save_selected(tmpdir, layer_data_and_types):
     assert not os.path.isdir(path)
 
     # Write data
-    layers.save(path, selected=True, plugin=BUILTINS)
+    layers.save(path, selected=True, plugin=builtins.name)
 
     # Check folder exists
     assert os.path.isdir(path)
@@ -416,6 +430,9 @@ def test_layers_save_selected(tmpdir, layer_data_and_types):
 @pytest.mark.filterwarnings('ignore:`np.int` is a deprecated alias for')
 def test_layers_save_svg(tmpdir, layers, napari_svg_name):
     """Test saving all layer data to an svg."""
+    pm = npe2.PluginManager.instance()
+    pm.register(npe2.PluginManifest.from_distribution('napari-svg'))
+
     path = os.path.join(tmpdir, 'layers_file.svg')
 
     # Check file does not exist
@@ -528,3 +545,36 @@ def test_name_uniqueness():
     layers.append(Image(np.random.random((10, 15)), name="Image"))
     layers.append(Image(np.random.random((10, 15)), name="Image"))
     assert [x.name for x in layers] == ['Image [1]', 'Image', 'Image [2]']
+
+
+def test_readd_layers():
+    layers = LayerList()
+    imgs = []
+    for _i in range(5):
+        img = Image(np.random.rand(10, 10, 10))
+        layers.append(img)
+        imgs.append(img)
+
+    assert layers == imgs
+
+    with pytest.raises(ValueError):
+        layers.append(imgs[1])
+    assert layers == imgs
+
+    layers[1] = layers[1]
+    assert layers == imgs
+
+    with pytest.raises(ValueError):
+        layers[1] = layers[2]
+    assert layers == imgs
+
+    layers[:3] = layers[:3]
+    assert layers == imgs
+
+    # invert a section
+    layers[:3] = layers[2::-1]
+    assert set(layers) == set(imgs)
+
+    with pytest.raises(ValueError):
+        layers[:3] = layers[:]
+    assert set(layers) == set(imgs)
