@@ -61,7 +61,8 @@ multi_channel_test_data = [
     ((), {'translate': MULTI_TUPLES}),
     ((), {'blending': 'translucent'}),
     ((), {'metadata': {'hi': 'there'}}),
-    ((), {'metadata': {k: v for k, v in MULTI_TUPLES}}),
+    ((), {'metadata': dict(MULTI_TUPLES)}),
+    ((), {'experimental_clipping_planes': []}),
 ]
 
 ids = [
@@ -89,6 +90,7 @@ ids = [
     'blending',
     'metadata_broadcast',
     'metadata_multi',
+    'empty_clipping_planes',
 ]
 
 
@@ -117,11 +119,25 @@ def test_multichannel(shape, kwargs):
             else:
                 assert viewer.layers[i].colormap.name == base_colormaps[i]
         if 'blending' not in kwargs:
-            assert viewer.layers[i].blending == 'additive'
+            assert (
+                viewer.layers[i].blending == 'translucent_no_depth'
+                if i == 0
+                else 'additive'
+            )
         for key, expectation in kwargs.items():
             # broadcast exceptions
-            if key in {'scale', 'translate', 'contrast_limits', 'metadata'}:
-                expectation = ensure_sequence_of_iterables(expectation)
+            if key in {
+                'scale',
+                'translate',
+                'rotate',
+                'shear',
+                'contrast_limits',
+                'metadata',
+                'experimental_clipping_planes',
+            }:
+                expectation = ensure_sequence_of_iterables(
+                    expectation, repeat_empty=True
+                )
             elif key == 'colormap' and expectation is not None:
                 if isinstance(expectation, list):
                     exp = [ensure_colormap(c).name for c in expectation]
@@ -135,7 +151,10 @@ def test_multichannel(shape, kwargs):
             result = getattr(viewer.layers[i], key)
             if key == 'colormap':  # colormaps are tuples of (name, cmap)
                 result = result.name
-            assert np.all(result == expectation[i])
+            if isinstance(result, np.ndarray):
+                np.testing.assert_almost_equal(result, expectation[i])
+            else:
+                assert result == expectation[i]
 
 
 def test_multichannel_multiscale():
