@@ -4,17 +4,18 @@ Loads chunks synchronously, or asynchronously using worker threads or
 processes. A chunk could be an OctreeChunk or it could be a pre-Octree
 array from the Image class, time-series or multi-scale.
 """
+
 import logging
 from concurrent.futures import Future
-from contextlib import contextmanager
+from contextlib import contextmanager, suppress
 from typing import Callable, Dict, List, Optional, Tuple
 
-from ....utils.config import octree_config
-from ....utils.events import EmitterGroup
-from ._cache import ChunkCache
-from ._info import LayerInfo, LoadType
-from ._pool_group import LoaderPoolGroup
-from ._request import ChunkRequest
+from napari.components.experimental.chunk._cache import ChunkCache
+from napari.components.experimental.chunk._info import LayerInfo, LoadType
+from napari.components.experimental.chunk._pool_group import LoaderPoolGroup
+from napari.components.experimental.chunk._request import ChunkRequest
+from napari.utils.config import octree_config
+from napari.utils.events import EmitterGroup
 
 LOGGER = logging.getLogger("napari.loader")
 
@@ -35,7 +36,7 @@ class ChunkLoader:
         We only signal one event: chunk_loaded.
     """
 
-    def __init__(self):
+    def __init__(self) -> None:
         _setup_logging(octree_config)
 
         loader_config = octree_config['loader_defaults']
@@ -47,10 +48,7 @@ class ChunkLoader:
         self.layer_map: Dict[int, LayerInfo] = {}
         self.cache: ChunkCache = ChunkCache()
 
-        self.events = EmitterGroup(
-            source=self, auto_connect=True, chunk_loaded=None
-        )
-
+        self.events = EmitterGroup(source=self, chunk_loaded=None)
         self._loaders = LoaderPoolGroup(octree_config, self._on_done)
 
     def get_info(self, layer_id: int) -> Optional[LayerInfo]:
@@ -264,10 +262,8 @@ class ChunkLoader:
         Layer
             The layer that was deleted.
         """
-        try:
+        with suppress(KeyError):
             del self.layer_map[id(layer)]
-        except KeyError:
-            pass  # We weren't tracking that layer yet.
 
     def wait_for_all(self):
         """Wait for all in-progress requests to finish."""
@@ -275,7 +271,8 @@ class ChunkLoader:
 
         for future_list in self._futures.values():
             # Result blocks until the future is done or cancelled
-            map(lambda x: x.result(), future_list)
+            for x in future_list:
+                x.result()
 
     def wait_for_data_id(self, data_id: int) -> None:
         """Wait for the given data to be loaded.
@@ -301,7 +298,8 @@ class ChunkLoader:
 
         # Calling result() will block until the future has finished or was
         # cancelled.
-        map(lambda x: x.result(), future_list)
+        for x in future_list:
+            x.result()
         del self._futures[data_id]
 
     def shutdown(self) -> None:
@@ -319,8 +317,10 @@ def synchronous_loading(enabled):
     """
     previous = chunk_loader.force_synchronous
     chunk_loader.force_synchronous = enabled
-    yield
-    chunk_loader.force_synchronous = previous
+    try:
+        yield
+    finally:
+        chunk_loader.force_synchronous = previous
 
 
 def wait_for_async():
