@@ -107,7 +107,10 @@ def _unlink_selected_layers(ll: LayerList):
 
 
 def _select_linked_layers(ll: LayerList):
-    ll.selection.update(get_linked_layers(*ll.selection))
+    linked_layers_in_list = [
+        x for x in get_linked_layers(*ll.selection) if x in ll
+    ]
+    ll.selection.update(linked_layers_in_list)
 
 
 def _convert_dtype(ll: LayerList, mode='int64'):
