@@ -1,8 +1,8 @@
 from collections import OrderedDict
 from enum import auto
 
-from ...utils.misc import StringEnum
-from ...utils.translations import trans
+from napari.utils.misc import StringEnum
+from napari.utils.translations import trans
 
 
 class Interpolation(StringEnum):
@@ -15,7 +15,7 @@ class Interpolation(StringEnum):
     """
 
     BESSEL = auto()
-    BICUBIC = auto()
+    CUBIC = auto()
     LINEAR = auto()
     BLACKMAN = auto()
     CATROM = auto()
@@ -29,11 +29,12 @@ class Interpolation(StringEnum):
     NEAREST = auto()
     SPLINE16 = auto()
     SPLINE36 = auto()
+    CUSTOM = auto()
 
     @classmethod
     def view_subset(cls):
         return (
-            cls.BICUBIC,
+            cls.CUBIC,
             cls.LINEAR,
             cls.KAISER,
             cls.NEAREST,
@@ -41,18 +42,6 @@ class Interpolation(StringEnum):
         )
 
 
-class Mode(StringEnum):
-    """
-    Mode: Interactive mode. The normal, default mode is PAN_ZOOM, which
-    allows for normal interactivity with the canvas.
-
-    TRANSFORM allows for manipulation of the layer transform.
-    """
-
-    TRANSFORM = auto()
-    PAN_ZOOM = auto()
-
-
 class ImageRendering(StringEnum):
     """Rendering: Rendering mode for the layer.
 
