@@ -1,8 +1,10 @@
 import time
 
+import dask
 import dask.array as da
 import numpy as np
 import pytest
+import skimage
 from hypothesis import given
 from hypothesis.extra.numpy import array_shapes
 from skimage.transform import pyramid_gaussian
@@ -52,15 +54,18 @@ def test_guess_multiscale():
     data = tuple(data)
     assert guess_multiscale(data)[0]
 
+    if skimage.__version__ > '0.19':
+        pyramid_kwargs = {'channel_axis': None}
+    else:
+        pyramid_kwargs = {'multichannel': False}
+
     data = tuple(
-        pyramid_gaussian(np.random.random((10, 15)), multichannel=False)
+        pyramid_gaussian(np.random.random((10, 15)), **pyramid_kwargs)
     )
     assert guess_multiscale(data)[0]
 
     data = np.asarray(
-        tuple(
-            pyramid_gaussian(np.random.random((10, 15)), multichannel=False)
-        ),
+        tuple(pyramid_gaussian(np.random.random((10, 15)), **pyramid_kwargs)),
         dtype=object,
     )
     assert guess_multiscale(data)[0]
@@ -70,6 +75,18 @@ def test_guess_multiscale():
     data = [da.ones((s,) * 3), da.ones((s // 2,) * 3), da.ones((s // 4,) * 3)]
     assert guess_multiscale(data)[0]
 
+    # Test for overflow in calculating array sizes
+    s = 17179869184
+    data = [
+        da.from_delayed(
+            dask.delayed(lambda: None), shape=(s,) * 2, dtype=np.float64
+        ),
+        da.from_delayed(
+            dask.delayed(lambda: None), shape=(s // 2,) * 2, dtype=np.float64
+        ),
+    ]
+    assert guess_multiscale(data)[0]
+
 
 def test_guess_multiscale_strip_single_scale():
     data = [np.empty((10, 10))]
@@ -80,9 +97,7 @@ def test_guess_multiscale_strip_single_scale():
 
 def test_guess_multiscale_non_array_list():
     """Check that non-decreasing list input raises ValueError"""
-    data = [
-        np.empty((10, 15, 6)),
-    ] * 2  # noqa: E231
+    data = [np.empty((10, 15, 6))] * 2
     with pytest.raises(ValueError):
         _, _ = guess_multiscale(data)
 
