@@ -7,16 +7,16 @@ from __future__ import annotations
 import logging
 from typing import TYPE_CHECKING, List, Set
 
-from ._chunk_set import ChunkSet
-from .octree import Octree
+from napari.layers.image.experimental._chunk_set import ChunkSet
+from napari.layers.image.experimental.octree import Octree
 
 if TYPE_CHECKING:
-    from ....components.experimental.chunk import (
+    from napari.components.experimental.chunk import (
         ChunkRequest,
         LayerRef,
         OctreeLocation,
     )
-    from .octree_chunk import OctreeChunk
+    from napari.layers.image.experimental.octree_chunk import OctreeChunk
 
 
 LOGGER = logging.getLogger("napari.octree.loader")
@@ -80,7 +80,7 @@ class OctreeLoader:
         A weak reference to the layer the octree lives in.
     """
 
-    def __init__(self, octree: Octree, layer_ref: LayerRef):
+    def __init__(self, octree: Octree, layer_ref: LayerRef) -> None:
         self._octree = octree
         self._layer_ref = layer_ref
 
@@ -189,9 +189,10 @@ class OctreeLoader:
             # The ideal level is priority 0, 1 is one level above idea, etc.
             priority = chunk.location.level_index - ideal_level
 
+            if chunk.needs_load:
+                self._load_chunk(chunk, priority)
+
             if chunk.in_memory:
-                drawable.append(chunk)
-            elif chunk.needs_load and self._load_chunk(chunk, priority):
                 drawable.append(chunk)  # It was a sync load, ready to draw.
 
         # Useful for debugging but very spammy.
@@ -232,14 +233,14 @@ class OctreeLoader:
             best_ancestor_index = level_indices.index(min(level_indices))
             # Take the last common ancestor which will be the most recent
             return [common_ancestors[best_ancestor_index]]
-        else:
-            # No in memory common ancestors were found so return the root tile.
-            # We say create=True because the root is not part of the current
-            # intersection. However since it's permanent once created and
-            # loaded it should always be available. As long as we don't garbage
-            # collect it!
-            root_tile = self._octree.levels[-1].get_chunk(0, 0, create=True)
-            return [root_tile]
+
+        # No in memory common ancestors were found so return the root tile.
+        # We say create=True because the root is not part of the current
+        # intersection. However since it's permanent once created and
+        # loaded it should always be available. As long as we don't garbage
+        # collect it!
+        root_tile = self._octree.levels[-1].get_chunk(0, 0, create=True)
+        return [root_tile]
 
     def _get_permanent_chunks(self) -> List[OctreeChunk]:
         """Get any permanent chunks we want to always draw.
@@ -303,10 +304,7 @@ class OctreeLoader:
 
         # If the ideal chunk is in memory then we'll want to draw that one
         # too though
-        if ideal_chunk.in_memory:
-            best_in_memory_chunk = [ideal_chunk]
-        else:
-            best_in_memory_chunk = []
+        best_in_memory_chunk = [ideal_chunk] if ideal_chunk.in_memory else []
 
         # First get any direct children which are in memory. Do not create
         # OctreeChunks or use children that are not already in memory
@@ -345,15 +343,14 @@ class OctreeLoader:
         # If the closest ancestor is drawn just take that one
         if len(ancestors) > 0 and ancestors == drawn_ancestors:
             return children + drawn_ancestors + best_in_memory_chunk
-        else:
-            # If the ideal chunk is in memory take that one
-            if len(best_in_memory_chunk) > 0:
-                return children + drawn_ancestors + best_in_memory_chunk
-            else:
-                # Otherwise that the close in memory ancestor
-                return children + drawn_ancestors + ancestors
+        # If the ideal chunk is in memory take that one
+        if len(best_in_memory_chunk) > 0:
+            return children + drawn_ancestors + best_in_memory_chunk
 
-    def _load_chunk(self, octree_chunk: OctreeChunk, priority: int) -> None:
+        # Otherwise that the close in memory ancestor
+        return children + drawn_ancestors + ancestors
+
+    def _load_chunk(self, octree_chunk: OctreeChunk, priority: int) -> bool:
         """Load the data for one OctreeChunk.
 
         Parameters
@@ -376,7 +373,7 @@ class OctreeLoader:
         # Mark that this chunk is being loaded.
         octree_chunk.loading = True
 
-        from ....components.experimental.chunk import (
+        from napari.components.experimental.chunk import (
             ChunkRequest,
             chunk_loader,
         )
@@ -418,7 +415,7 @@ class OctreeLoader:
             The set of chunks the loader can see.
         """
 
-        from ....components.experimental.chunk import chunk_loader
+        from napari.components.experimental.chunk import chunk_loader
 
         def _should_cancel(chunk_request: ChunkRequest) -> bool:
             """Cancel if we are no longer seeing this location."""
