@@ -1,3 +1,4 @@
+import copy
 import itertools
 import time
 from dataclasses import dataclass
@@ -5,14 +6,14 @@ from tempfile import TemporaryDirectory
 from typing import List
 
 import numpy as np
+import numpy.testing as npt
 import pandas as pd
 import pytest
 import xarray as xr
 import zarr
 from numpy.core.numerictypes import issubdtype
 from numpy.testing import assert_array_almost_equal, assert_raises
-from skimage import data
-from vispy.color import Colormap as VispyColormap
+from skimage import data as sk_data
 
 from napari._tests.utils import check_layer_world_data_extent
 from napari.components import ViewerModel
@@ -20,7 +21,30 @@ from napari.layers import Labels
 from napari.layers.labels._labels_constants import LabelsRendering
 from napari.layers.labels._labels_utils import get_contours
 from napari.utils import Colormap
-from napari.utils.colormaps import label_colormap, low_discrepancy_image
+from napari.utils.colormaps import (
+    CyclicLabelColormap,
+    DirectLabelColormap,
+    label_colormap,
+)
+
+
+@pytest.fixture
+def direct_colormap():
+    """Return a DirectLabelColormap."""
+    return DirectLabelColormap(
+        color_dict={
+            0: [0, 0, 0, 0],
+            1: [1, 0, 0, 1],
+            2: [0, 1, 0, 1],
+            None: [0, 0, 1, 1],
+        }
+    )
+
+
+@pytest.fixture
+def random_colormap():
+    """Return a LabelColormap."""
+    return label_colormap(50)
 
 
 def test_random_labels():
@@ -228,6 +252,7 @@ def test_blending():
     assert layer.blending == 'opaque'
 
 
+@pytest.mark.filterwarnings("ignore:.*seed is deprecated.*")
 def test_seed():
     """Test setting seed."""
     np.random.seed(0)
@@ -241,28 +266,41 @@ def test_seed():
     layer = Labels(data, seed=0.7)
     assert layer.seed == 0.7
 
-    # ensure setting seed triggers
-    # recalculation of _all_vals
-    _all_vals_07 = layer._all_vals.copy()
+    # ensure setting seed updates the random colormap
+    mapped_07 = layer.colormap.map(layer.data)
     layer.seed = 0.4
-    _all_vals_04 = layer._all_vals.copy()
+    mapped_04 = layer.colormap.map(layer.data)
     assert_raises(
-        AssertionError, assert_array_almost_equal, _all_vals_04, _all_vals_07
+        AssertionError, assert_array_almost_equal, mapped_07, mapped_04
     )
 
 
 def test_num_colors():
-    """Test setting number of colors in colormap."""
+    """Test setting number of colors in colormap with deprecated API."""
     np.random.seed(0)
     data = np.random.randint(20, size=(10, 15))
     layer = Labels(data)
-    assert layer.num_colors == 50
 
-    layer.num_colors = 80
-    assert layer.num_colors == 80
+    with pytest.warns(FutureWarning, match='num_colors is deprecated'):
+        assert layer.num_colors == 50
 
-    layer = Labels(data, num_colors=60)
-    assert layer.num_colors == 60
+    with pytest.warns(FutureWarning, match='num_colors is deprecated'):
+        layer.num_colors = 80
+
+    assert len(layer.colormap) == 80
+
+    with pytest.warns(FutureWarning, match='num_colors is deprecated'):
+        layer = Labels(data, num_colors=60)
+
+    assert len(layer.colormap) == 60
+
+    with pytest.raises(ValueError, match=r".*Only up to 2\*\*16=65535 colors"):
+        with pytest.warns(FutureWarning, match='num_colors is deprecated'):
+            layer.num_colors = 2**17
+
+    with pytest.raises(ValueError, match=r".*Only up to 2\*\*16=65535 colors"):
+        with pytest.warns(FutureWarning, match='num_colors is deprecated'):
+            Labels(data, num_colors=2**17)
 
 
 def test_properties():
@@ -386,17 +424,26 @@ def test_label_colormap():
     # Make sure color 0 is transparent
     assert not np.any(colormap.map([0.0]))
 
-    # Test that out-of-range values map to last value
-    assert np.all(colormap.map([1.0, 1.1, 2.0]) == colormap.colors[-1])
+    # test that all four colors are represented in a large set of random
+    # labels.
+    # we choose non-zero labels, and then there should not be any transparent
+    # values.
+    labels = np.random.randint(1, 2**23, size=(100, 100)).astype(np.float32)
+    colormapped = colormap.map(labels)
+    linear = np.reshape(colormapped, (-1, 4))
+    unique = np.unique(linear, axis=0)
+    assert len(unique) == 4
 
 
 def test_custom_color_dict():
     """Test custom color dict."""
     np.random.seed(0)
     data = np.random.randint(20, size=(10, 15))
-    layer = Labels(
-        data, color={2: 'white', 4: 'red', 8: 'blue', 16: 'red', 32: 'blue'}
-    )
+    with pytest.warns(FutureWarning, match='Labels.color is deprecated'):
+        layer = Labels(
+            data,
+            color={2: 'white', 4: 'red', 8: 'blue', 16: 'red', 32: 'blue'},
+        )
 
     # test with custom color dict
     assert type(layer.get_color(2)) == np.ndarray
@@ -405,77 +452,13 @@ def test_custom_color_dict():
     assert (layer.get_color(4) == layer.get_color(16)).all()
     assert (layer.get_color(8) == layer.get_color(32)).all()
 
-    # Test to see if our label mapped control points map to those in the colormap
-    # with an extra half step.
-    local_controls = np.array(
-        sorted(np.unique([*layer._label_color_index.values(), 1.0]))
-    )
-    colormap_controls = np.array(layer._colormap.controls)
-    assert np.max(np.abs(local_controls - colormap_controls)) == pytest.approx(
-        0.5 / (len(colormap_controls) - 1)
-    )
-
     # test disable custom color dict
     # should not initialize as white since we are using random.seed
-    layer.color_mode = 'auto'
+    with pytest.warns(FutureWarning, match='Labels.color_mode is deprecated'):
+        layer.color_mode = 'auto'
     assert not (layer.get_color(1) == np.array([1.0, 1.0, 1.0, 1.0])).all()
 
 
-def test_large_custom_color_dict():
-    """Confirm that the napari & vispy colormaps behave the same."""
-
-    label_count = 897
-    colors = {
-        color: (0, (color / 256.0) / 256.0, (color % 256) / 256.0)
-        for color in range(label_count)
-    }
-    data, _ = np.meshgrid(range(label_count), range(5))
-    layer = Labels(data, color=colors)
-
-    # Get color list using layer interface & napari.utils.colormap.ColorMap
-    label_color = layer.get_color(list(range(label_count)))
-
-    # Get the color by converting to control points with the layer and passing
-    # that to a vispy.color.colormap.Colormap
-    vispy_colormap = VispyColormap(
-        colors=layer.colormap.colors,
-        controls=layer.colormap.controls,
-        interpolation='zero',
-    )
-    label_color_controls = [
-        layer._label_color_index[x] for x in range(label_count)
-    ]
-    vispy_colors = vispy_colormap.map(np.array(list(label_color_controls)))
-
-    assert (label_color == vispy_colors).all()
-
-
-def test_warning_too_many_colors():
-    label_count = 1500
-    colors = {
-        color: (0, (color / 256.0) / 256.0, (color % 256) / 256.0)
-        for color in range(label_count)
-    }
-    data, _ = np.meshgrid(range(label_count), range(5))
-    with pytest.warns(UserWarning):
-        # Expect a warning for 1500 colors > 1024 in LUT
-        Labels(data, color=colors)
-
-
-def test_add_colors():
-    """Test adding new colors"""
-    data = np.random.randint(20, size=(40, 40))
-    layer = Labels(data)
-    assert len(layer._all_vals) == np.max(data) + 1
-
-    layer.selected_label = 51
-    assert len(layer._all_vals) == 52
-
-    layer.show_selected_label = True
-    layer.selected_label = 53
-    assert len(layer._all_vals) == 54
-
-
 def test_metadata():
     """Test setting labels metadata."""
     np.random.seed(0)
@@ -586,6 +569,7 @@ def test_n_edit_dimensions():
             np.zeros((9, 10), dtype=np.uint32),
         ),
     ],
+    ids=['touching objects', 'touching border', 'full array'],
 )
 def test_contour(input_data, expected_data_view):
     """Test changing contour."""
@@ -594,7 +578,8 @@ def test_contour(input_data, expected_data_view):
     np.testing.assert_array_equal(layer.data, input_data)
 
     np.testing.assert_array_equal(
-        layer._raw_to_displayed(input_data), layer._data_view
+        layer._raw_to_displayed(input_data.astype(np.float32)),
+        layer._data_view,
     )
     data_view_before_contour = layer._data_view.copy()
 
@@ -609,7 +594,7 @@ def test_contour(input_data, expected_data_view):
         layer._data_view,
         np.where(
             expected_data_view > 0,
-            low_discrepancy_image(expected_data_view),
+            expected_data_view,
             0,
         ),
     )
@@ -632,6 +617,23 @@ def test_contour(input_data, expected_data_view):
         layer.contour = -1
 
 
+@pytest.mark.parametrize("background_num", [0, 1, 2, -1])
+def test_background_label(background_num):
+    data = np.zeros((10, 10), dtype=np.int32)
+    data[1:-1, 1:-1] = 1
+    data[2:-2, 2:-2] = 2
+    data[4:-4, 4:-4] = -1
+
+    layer = Labels(data)
+    layer.colormap = label_colormap(49, background_value=background_num)
+    np.testing.assert_array_equal(
+        layer._data_view == 0, data == background_num
+    )
+    np.testing.assert_array_equal(
+        layer._data_view != 0, data != background_num
+    )
+
+
 def test_contour_large_new_labels():
     """Check that new labels larger than the lookup table work in contour mode.
 
@@ -682,6 +684,28 @@ def test_contour_local_updates():
     )
 
 
+def test_data_setitem_multi_dim():
+    """
+    this test checks if data_setitem works when some of the indices are
+    outside currently rendered slice
+    """
+    # create zarr zeros array in memory
+    data = zarr.zeros((10, 10, 10), chunks=(5, 5, 5), dtype=np.uint32)
+    labels = Labels(data)
+    labels.data_setitem(
+        (np.array([0, 1, 1]), np.array([1, 1, 2]), np.array([0, 0, 0])),
+        [1, 2, 0],
+    )
+
+
+def test_data_setitiem_transposed_axes():
+    data = np.zeros((10, 100), dtype=np.uint32)
+    labels = Labels(data)
+    labels.data_setitem((np.array([9]), np.array([99])), 1)
+    labels._slice_dims([0, 0], 2, [1, 0])
+    labels.data_setitem((np.array([9]), np.array([99])), 2)
+
+
 def test_selecting_label():
     """Test selecting label."""
     np.random.seed(0)
@@ -715,14 +739,16 @@ def test_show_selected_label():
     original_color = layer.get_color(1)
 
     layer.show_selected_label = True
-    original_background_color = layer.get_color(layer._background_label)
+    original_background_color = layer.get_color(
+        layer.colormap.background_value
+    )
     none_color = layer.get_color(None)
     layer.selected_label = 1
 
     # color of selected label has not changed
     assert np.allclose(layer.get_color(layer.selected_label), original_color)
 
-    current_background_color = layer.get_color(layer._background_label)
+    current_background_color = layer.get_color(layer.colormap.background_value)
     # color of background is background color
     assert current_background_color == original_background_color
 
@@ -806,7 +832,7 @@ def test_paint_2d():
 
 
 def test_paint_2d_xarray():
-    """Test the memory usage of painting an xarray indirectly via timeout."""
+    """Test the memory usage of painting a xarray indirectly via timeout."""
     now = time.monotonic()
     data = xr.DataArray(np.zeros((3, 3, 1024, 1024), dtype=np.uint32))
 
@@ -897,7 +923,7 @@ def test_message():
     data = np.random.randint(20, size=(10, 15))
     layer = Labels(data)
     msg = layer.get_status((0, 0))
-    assert type(msg) == dict
+    assert isinstance(msg, dict)
 
 
 def test_thumbnail():
@@ -909,11 +935,22 @@ def test_thumbnail():
     assert layer.thumbnail.shape == layer._thumbnail_shape
 
 
+@pytest.mark.parametrize("value", [1, 10, 50, -2, -10])
+@pytest.mark.parametrize("dtype", [np.int8, np.int32])
+def test_thumbnail_single_color(value, dtype):
+    labels = Labels(np.full((10, 10), value, dtype=dtype), opacity=1)
+    labels._update_thumbnail()
+    mid_point = tuple(np.array(labels.thumbnail.shape[:2]) // 2)
+    npt.assert_array_equal(
+        labels.thumbnail[mid_point], labels.get_color(value) * 255
+    )
+
+
 def test_world_data_extent():
     """Test extent after applying transforms."""
     np.random.seed(0)
     shape = (6, 10, 15)
-    data = np.random.randint(20, size=(shape))
+    data = np.random.randint(20, size=shape)
     layer = Labels(data)
     extent = np.array(((0,) * 3, shape))
     check_layer_world_data_extent(layer, extent, (3, 1, 1), (10, 20, 5), True)
@@ -938,7 +975,7 @@ def test_undo_redo(
     preserve_labels,
     n_dimensional,
 ):
-    blobs = data.binary_blobs(length=64, volume_fraction=0.3, n_dim=3)
+    blobs = sk_data.binary_blobs(length=64, volume_fraction=0.3, n_dim=3)
     layer = Labels(blobs)
     data_history = [blobs.copy()]
     layer.brush_size = brush_size
@@ -1011,40 +1048,21 @@ def test_ndim_paint():
     )
 
 
-def test_switching_display_func():
-    label_data = np.random.randint(2**25, 2**25 + 5, size=(50, 50))
-    layer = Labels(label_data)
-    assert layer._color_lookup_func == layer._lookup_with_low_discrepancy_image
-
-    label_data = np.random.randint(0, 5, size=(50, 50))
-    layer = Labels(label_data)
-    assert layer._color_lookup_func == layer._lookup_with_index
-
-
 def test_cursor_size_with_negative_scale():
     layer = Labels(np.zeros((5, 5), dtype=int), scale=[-1, -1])
     layer.mode = 'paint'
     assert layer.cursor_size > 0
 
 
-def test_switching_display_func_during_slicing():
-    label_array = (5e6 * np.ones((2, 2, 2))).astype(np.uint64)
-    label_array[0, :, :] = [[0, 1], [2, 3]]
+@pytest.mark.xfail(
+    reason="labels are converted to float32 before being mapped"
+)
+def test_large_label_values():
+    label_array = 2**23 + np.arange(4, dtype=np.uint64).reshape((2, 2))
     layer = Labels(label_array)
-    layer._slice_dims(point=(1, 0, 0))
-    assert layer._color_lookup_func == layer._lookup_with_low_discrepancy_image
-    assert layer._all_vals.size < 1026
+    mapped = layer._random_colormap.map(layer.data)
 
-
-def test_add_large_colors():
-    label_array = (5e6 * np.ones((2, 2, 2))).astype(np.uint64)
-    label_array[0, :, :] = [[0, 1], [2, 3]]
-    layer = Labels(label_array)
-    assert len(layer._all_vals) == 4
-
-    layer.show_selected_label = True
-    layer.selected_label = int(5e6)
-    assert layer._all_vals.size < 1026
+    assert len(np.unique(mapped.reshape((-1, 4)), axis=0)) == 4
 
 
 def test_fill_tensorstore():
@@ -1414,33 +1432,42 @@ def test_is_default_color():
     layer = Labels(data)
 
     # layer gets instantiated with defaults
-    current_color = layer.color
+    current_color = layer._direct_colormap.color_dict
     assert layer._is_default_colors(current_color)
 
     # setting color to default colors doesn't update color mode
-    layer.color = current_color
-    assert layer.color_mode == 'auto'
+    layer.colormap = DirectLabelColormap(color_dict=current_color)
+    assert isinstance(layer.colormap, CyclicLabelColormap)
+    with pytest.warns(FutureWarning, match='Labels.color_mode is deprecated'):
+        assert layer.color_mode == 'auto'
 
     # new colors are not default
-    new_color = {0: 'white', 1: 'red', 3: 'green'}
+    new_color = {0: 'white', 1: 'red', 3: 'green', None: 'blue'}
     assert not layer._is_default_colors(new_color)
     # setting the color with non-default colors updates color mode
-    layer.color = new_color
-    assert layer.color_mode == 'direct'
+    layer.colormap = DirectLabelColormap(color_dict=new_color)
+    assert isinstance(layer.colormap, DirectLabelColormap)
+    with pytest.warns(FutureWarning, match='Labels.color_mode is deprecated'):
+        assert layer.color_mode == 'direct'
 
 
 def test_large_labels_direct_color():
     """Make sure direct color works with large label ranges"""
+    pytest.importorskip('numba')
     data = np.array([[0, 1], [2**16, 2**20]], dtype=np.uint32)
     colors = {1: 'white', 2**16: 'green', 2**20: 'magenta'}
     layer = Labels(data)
-    layer.color = colors
+    with pytest.warns(FutureWarning, match='Labels.color is deprecated'):
+        layer.color = colors
 
-    assert layer.color_mode == 'direct'
+    with pytest.warns(FutureWarning, match='Labels.color_mode is deprecated'):
+        assert layer.color_mode == 'direct'
     np.testing.assert_allclose(layer.get_color(2**20), [1.0, 0.0, 1.0, 1.0])
 
 
-def test_invalidate_cache_when_change_color_mode():
+def test_invalidate_cache_when_change_color_mode(
+    direct_colormap, random_colormap
+):
     """Checks if the cache is invalidated when color mode is changed."""
     data = np.zeros((4, 10), dtype=np.int32)
     data[1, :] = np.arange(0, 10)
@@ -1448,13 +1475,13 @@ def test_invalidate_cache_when_change_color_mode():
     layer = Labels(data)
     layer.selected_label = 0
     gt_auto = layer._raw_to_displayed(layer._slice.image.raw)
-    assert gt_auto.dtype == np.float32
+    assert gt_auto.dtype == np.uint8
 
-    layer.color_mode = 'direct'
+    layer.colormap = direct_colormap
     layer._cached_labels = None
-    assert layer._raw_to_displayed(layer._slice.image.raw).dtype == np.float32
+    assert layer._raw_to_displayed(layer._slice.image.raw).dtype == np.uint8
 
-    layer.color_mode = 'auto'
+    layer.colormap = random_colormap
     # If the cache is not invalidated, it returns colors for
     # the direct color mode instead of the color for the auto mode
     assert np.allclose(
@@ -1467,12 +1494,24 @@ def test_color_mapping_when_color_is_changed():
 
     data = np.zeros((4, 5), dtype=np.int32)
     data[1, :] = np.arange(0, 5)
-    layer = Labels(data, color={1: 'green', 2: 'red', 3: 'white'})
+    layer = Labels(
+        data,
+        colormap=DirectLabelColormap(
+            color_dict={1: 'green', 2: 'red', 3: 'white', None: 'black'}
+        ),
+    )
     gt_direct_3colors = layer._raw_to_displayed(layer._slice.image.raw)
 
-    layer = Labels(data, color={1: 'green', 2: 'red'})
-    assert layer._raw_to_displayed(layer._slice.image.raw).dtype == np.float32
-    layer.color = {1: 'green', 2: 'red', 3: 'white'}
+    layer = Labels(
+        data,
+        colormap=DirectLabelColormap(
+            color_dict={1: 'green', 2: 'red', None: 'black'}
+        ),
+    )
+    assert layer._raw_to_displayed(layer._slice.image.raw).dtype == np.uint8
+    layer.colormap = DirectLabelColormap(
+        color_dict={1: 'green', 2: 'red', 3: 'white', None: 'black'}
+    )
 
     assert np.allclose(
         layer._raw_to_displayed(layer._slice.image.raw), gt_direct_3colors
@@ -1484,39 +1523,58 @@ def test_color_mapping_with_show_selected_label():
 
     data = np.arange(5, dtype=np.int32)[:, np.newaxis].repeat(5, axis=1)
     layer = Labels(data)
-    mapped_colors_all = layer._raw_to_displayed(layer._slice.image.raw).copy()
+    mapped_colors_all = layer.colormap.map(data)
 
-    layer.selected_label = 1
     layer.show_selected_label = True
 
-    for selected_label in range(1, 5):
+    for selected_label in range(5):
         layer.selected_label = selected_label
         label_mask = data == selected_label
-        mapped_colors = layer._raw_to_displayed(layer._slice.image.raw)
+        mapped_colors = layer.colormap.map(data)
 
-        assert np.allclose(
+        npt.assert_allclose(
             mapped_colors[label_mask], mapped_colors_all[label_mask]
         )
-        assert np.allclose(mapped_colors[np.logical_not(label_mask)], 0)
+        npt.assert_allclose(mapped_colors[np.logical_not(label_mask)], 0)
 
     layer.show_selected_label = False
-    assert np.allclose(
-        layer._raw_to_displayed(layer._slice.image.raw), mapped_colors_all
-    )
+    assert np.allclose(layer.colormap.map(data), mapped_colors_all)
 
 
 def test_color_mapping_when_seed_is_changed():
     """Checks if the color mapping is updated when the color palette seed is changed."""
     np.random.seed(0)
     layer = Labels(np.random.randint(50, size=(10, 10)))
-    mapped_colors1 = layer._raw_to_displayed(layer._slice.image.raw)
+    mapped_colors1 = layer.colormap.map(
+        layer._to_vispy_texture_dtype(layer._slice.image.raw)
+    )
 
     layer.new_colormap()
-    mapped_colors2 = layer._raw_to_displayed(layer._slice.image.raw)
+    mapped_colors2 = layer.colormap.map(
+        layer._to_vispy_texture_dtype(layer._slice.image.raw)
+    )
 
     assert not np.allclose(mapped_colors1, mapped_colors2)
 
 
+@pytest.mark.parametrize('num_colors', [49, 50, 254, 255, 60000, 65534])
+def test_color_shuffling_above_num_colors(num_colors):
+    r"""Check that the color shuffle does not result in the same collisions.
+
+    See https://github.com/napari/napari/issues/6448.
+
+    Note that we don't support more than 2\ :sup:`16` colors, and behavior
+    with more colors is undefined, so we don't test it here.
+    """
+    labels = np.arange(1, 1 + 2 * (num_colors - 1)).reshape((2, -1))
+    layer = Labels(labels, colormap=label_colormap(num_colors - 1))
+    colors0 = layer.colormap.map(labels)
+    assert np.all(colors0[0] == colors0[1])
+    layer.new_colormap()
+    colors1 = layer.colormap.map(labels)
+    assert not np.all(colors1[0] == colors1[1])
+
+
 def test_negative_label():
     """Test negative label values are supported."""
     data = np.random.randint(low=-1, high=20, size=(10, 10))
@@ -1540,9 +1598,6 @@ def test_negative_label_slicing():
     assert tuple(layer.get_color(-2)) != tuple(layer.get_color(100))
 
 
-@pytest.mark.xfail(
-    reason='This is a known bug with the current label color implementation'
-)
 def test_negative_label_doesnt_flicker():
     data = np.array(
         [
@@ -1553,16 +1608,12 @@ def test_negative_label_doesnt_flicker():
     )
     layer = Labels(data)
     layer._slice_dims(point=(1, 0, 0))
-    # this is expected to fail: -1 doesn't trigger an index error in
-    # layer._all_vals, it instead just wraps to 5, the previous max label.
+    # This used to fail when negative values were used to index into _all_vals.
     assert tuple(layer.get_color(-1)) != tuple(layer.get_color(5))
     minus_one_color_original = tuple(layer.get_color(-1))
     layer.dims_point = (2, 0, 0)
     layer._set_view_slice()
-    # this is also expected to fail: when we switch layers, we see the 6
-    # label, which causes an index error, which triggers a recalculation of
-    # the label colors. Now -1 is seen so it is taken into account in the
-    # indexing calculation, and changes color
+
     assert tuple(layer.get_color(-1)) == minus_one_color_original
 
 
@@ -1604,6 +1655,43 @@ def test_labels_features_event():
     assert event_emitted
 
 
+def test_copy():
+    l1 = Labels(np.zeros((2, 4, 5), dtype=np.uint8))
+    l2 = copy.copy(l1)
+    l3 = Labels.create(*l1.as_layer_data_tuple())
+    assert l1.data is not l2.data
+    assert l1.data is l3.data
+
+
+@pytest.mark.parametrize(
+    "colormap,expected",
+    [
+        (label_colormap(49, 0.5), [0, 1]),
+        (
+            DirectLabelColormap(
+                color_dict={
+                    0: np.array([0, 0, 0, 0]),
+                    1: np.array([1, 0, 0, 1]),
+                    None: np.array([1, 1, 0, 1]),
+                }
+            ),
+            [1, 2],
+        ),
+    ],
+    ids=["auto", "direct"],
+)
+def test_draw(colormap, expected):
+    labels = Labels(np.zeros((30, 30), dtype=np.uint32))
+    labels.mode = "paint"
+    labels.colormap = colormap
+    labels.selected_label = 1
+    npt.assert_array_equal(np.unique(labels._slice.image.raw), [0])
+    npt.assert_array_equal(np.unique(labels._slice.image.view), expected[:1])
+    labels._draw(1, (15, 15), (15, 15))
+    npt.assert_array_equal(np.unique(labels._slice.image.raw), [0, 1])
+    npt.assert_array_equal(np.unique(labels._slice.image.view), expected)
+
+
 class TestLabels:
     @staticmethod
     def get_objects():
@@ -1612,5 +1700,5 @@ class TestLabels:
     def test_events_defined(self, event_define_check, obj):
         event_define_check(
             obj,
-            {"seed", "num_colors", "color"},
+            {"seed", "num_colors", "color", "seed_rng"},
         )
