@@ -1,10 +1,13 @@
 from dataclasses import dataclass, field
 from typing import List, Optional, Tuple, Union
+from unittest.mock import MagicMock
 
 import numpy as np
 import pytest
 
 from napari.layers import Points
+from napari.layers._tests._utils import compare_dicts
+from napari.layers.base import ActionType
 from napari.utils._proxies import ReadOnlyWrapper
 from napari.utils.interactions import (
     mouse_move_callbacks,
@@ -51,7 +54,7 @@ def create_known_points_layer_2d():
         testing when needing to guarantee no point is clicked on.
     """
     data = [[1, 3], [8, 4], [10, 10], [15, 4]]
-    known_non_point = [20, 30]
+    known_non_point = [10, 11]
     n_points = len(data)
 
     layer = Points(data, size=1)
@@ -470,6 +473,20 @@ def test_unselecting_points(create_known_points_layer_2d):
     # Check clicked point selected
     assert len(layer.selected_data) == 0
 
+    # check that this also works with scaled data and position near a point (see #5737)
+    # we are taking the first point and shiftling *slightly* more than the point size
+    layer.scale = 100, 100
+    pos = np.array(layer.data[0])
+    pos[1] += layer.size[0] * 2
+
+    event = read_only_event(type='mouse_press', position=pos)
+    mouse_press_callbacks(layer, event)
+    event = read_only_event(type='mouse_release', position=pos)
+    mouse_release_callbacks(layer, event)
+
+    # Check clicked point selected
+    assert len(layer.selected_data) == 0
+
 
 def test_selecting_all_points_with_drag_2d(create_known_points_layer_2d):
     """Select all points when drag box includes all of them."""
@@ -477,22 +494,30 @@ def test_selecting_all_points_with_drag_2d(create_known_points_layer_2d):
 
     layer.mode = 'select'
 
+    # drag a box that includes all the points
+    box_drag_begin = (20, 20)
+    box_drag_end = (0, 0)
+
     # Simulate click
-    event = read_only_event(type='mouse_press', position=known_non_point)
+    event = read_only_event(type='mouse_press', position=box_drag_begin)
     mouse_press_callbacks(layer, event)
 
     # Simulate drag start
     event = read_only_event(
-        type='mouse_move', is_dragging=True, position=known_non_point
+        type='mouse_move', is_dragging=True, position=box_drag_begin
     )
     mouse_move_callbacks(layer, event)
 
     # Simulate drag end
-    event = read_only_event(type='mouse_move', is_dragging=True)
+    event = read_only_event(
+        type='mouse_move', is_dragging=True, position=box_drag_end
+    )
     mouse_move_callbacks(layer, event)
 
     # Simulate release
-    event = read_only_event(type='mouse_release', is_dragging=True)
+    event = read_only_event(
+        type='mouse_release', is_dragging=True, position=box_drag_end
+    )
     mouse_release_callbacks(layer, event)
 
     # Check all points selected as drag box contains them
@@ -666,10 +691,7 @@ def test_drag_start_selection(
     layer.mode = 'select'
     layer.selected_data = pre_selection
 
-    if on_point:
-        initial_position = tuple(layer.data[0])
-    else:
-        initial_position = tuple(known_non_point)
+    initial_position = tuple(layer.data[0]) if on_point else (20, 20)
     zero_pos = [0, 0]
     initial_position_1 = tuple(layer.data[1])
     diff_data_1 = [
@@ -821,3 +843,57 @@ def test_drag_start_selection(
         assert False, 'Unreachable code'  # pragma: no cover
     assert layer._drag_box is None
     assert layer._drag_start is None
+
+
+def test_drag_point_with_mouse(create_known_points_layer_2d):
+    layer, n_points, _ = create_known_points_layer_2d
+    layer.events.data = MagicMock()
+    layer.mode = 'select'
+    old_data = (
+        layer.data.copy()
+    )  # ensure you have old data, not updated in place
+    layer.selected_data = {1}
+    initial_position = tuple(layer.data[1])
+
+    new_position = [0, 0]
+    modifier = []
+
+    event = read_only_event(
+        type='mouse_press', position=initial_position, modifiers=modifier
+    )
+    mouse_press_callbacks(layer, event)
+
+    # Required to assert before the changing event as otherwise layer.data for changing is updated in place.
+    changing_event = {
+        "value": old_data,
+        "action": ActionType.CHANGING,
+        "data_indices": (1,),
+        "vertex_indices": ((),),
+    }
+
+    def side_effect(*args, **kwargs):
+        if kwargs["action"] == ActionType.CHANGING:
+            assert compare_dicts(kwargs, changing_event)
+
+    layer.events.data.side_effect = side_effect
+    event = read_only_event(
+        type='mouse_move',
+        is_dragging=True,
+        position=new_position,
+        modifiers=modifier,
+    )
+    mouse_move_callbacks(layer, event)
+
+    event = read_only_event(
+        type='mouse_release', is_dragging=False, modifiers=modifier
+    )
+    mouse_release_callbacks(layer, event)
+
+    changed_event = {
+        "value": layer.data,
+        "action": ActionType.CHANGED,
+        "data_indices": (1,),
+        "vertex_indices": ((),),
+    }
+    assert not np.array_equal(layer.data, old_data)
+    assert compare_dicts(layer.events.data.call_args[1], changed_event)
