@@ -2,14 +2,15 @@ from abc import ABC, abstractmethod
 
 import numpy as np
 
-from ....utils.translations import trans
-from .._shapes_utils import (
+from napari.layers.shapes._shapes_utils import (
     is_collinear,
     path_to_mask,
     poly_to_mask,
     triangulate_edge,
     triangulate_face,
 )
+from napari.utils.misc import argsort
+from napari.utils.translations import trans
 
 
 class Shape(ABC):
@@ -94,8 +95,7 @@ class Shape(ABC):
         z_index=0,
         dims_order=None,
         ndisplay=2,
-    ):
-
+    ) -> None:
         self._dims_order = dims_order or list(range(2))
         self._ndisplay = ndisplay
         self.slice_key = None
@@ -118,16 +118,16 @@ class Shape(ABC):
     @abstractmethod
     def data(self):
         # user writes own docstring
-        raise NotImplementedError()
+        raise NotImplementedError
 
     @data.setter
     @abstractmethod
     def data(self, data):
-        raise NotImplementedError()
+        raise NotImplementedError
 
     @abstractmethod
     def _update_displayed_data(self):
-        raise NotImplementedError()
+        raise NotImplementedError
 
     @property
     def ndisplay(self):
@@ -351,7 +351,7 @@ class Shape(ABC):
             self.transform(transform)
             self.shift(-center)
 
-    def to_mask(self, mask_shape=None, zoom_factor=1, offset=[0, 0]):
+    def to_mask(self, mask_shape=None, zoom_factor=1, offset=(0, 0)):
         """Convert the shape vertices to a boolean mask.
 
         Set points to `True` if they are lying inside the shape if the shape is
@@ -423,11 +423,7 @@ class Shape(ABC):
                         self.slice_key[0, j], self.slice_key[1, j] + 1
                     )
                 j += 1
-            # equivalent to: displayed_order = np.argsort(self.dims_displayed)
-            dims_displayed = self.dims_displayed
-            displayed_order = sorted(
-                range(len(dims_displayed)), key=lambda x: dims_displayed[x]
-            )
+            displayed_order = argsort(self.dims_displayed)
             mask[tuple(slice_key)] = mask_p.transpose(displayed_order)
         else:
             mask = mask_p
