@@ -1,10 +1,8 @@
 from enum import Enum, auto
 
-from pydantic import Field
-
+from napari._pydantic_compat import Field
 from napari.utils.color import ColorValue
-
-from ...utils.events import EventedModel
+from napari.utils.events import EventedModel
 
 
 class NormalMode(Enum):
