@@ -1,6 +1,7 @@
 from enum import auto
 
-from ..utils.misc import StringEnum
+from napari.utils.compat import StrEnum
+from napari.utils.misc import StringEnum
 
 
 class LoopMode(StringEnum):
@@ -20,3 +21,11 @@ class LoopMode(StringEnum):
     ONCE = auto()
     LOOP = auto()
     BACK_AND_FORTH = auto()
+
+
+class BrushSizeOnMouseModifiers(StrEnum):
+    ALT = 'Alt'
+    CTRL = 'Control'
+    CTRL_ALT = 'Control+Alt'
+    CTRL_SHIFT = 'Control+Shift'
+    DISABLED = 'Disabled'  # a non-existent modifier that is never activated
