@@ -8,28 +8,31 @@ their custom classes or types should be converted into GUIs.  Then, when the
 end-user annotates one of their function arguments with a type hint using one
 of those custom classes, magicgui will know what to do with it.
 
+Because of headless tests the tests for this module are
+in napari/_tests/test_magicgui.py
 """
 from __future__ import annotations
 
 import weakref
 from functools import lru_cache, partial
-from typing import TYPE_CHECKING, Any, List, Optional, Set, Tuple, Type
+from typing import TYPE_CHECKING, Any, List, Optional, Tuple, Type
 
 from typing_extensions import get_args
 
-from ..utils._proxies import PublicOnlyProxy
+from napari.utils._proxies import PublicOnlyProxy
 
 if TYPE_CHECKING:
     from concurrent.futures import Future
 
+    from magicgui.widgets import FunctionGui
     from magicgui.widgets._bases import CategoricalWidget
 
-    from .._qt.qthreading import FunctionWorker
-    from ..layers import Layer
-    from ..viewer import Viewer
+    from napari._qt.qthreading import FunctionWorker
+    from napari.layers import Layer
+    from napari.viewer import Viewer
 
 
-def add_layer_data_to_viewer(gui, result, return_type):
+def add_layer_data_to_viewer(gui: FunctionGui, result: Any, return_type: Type):
     """Show a magicgui result in the viewer.
 
     This function will be called when a magicgui-decorated function has a
@@ -57,22 +60,18 @@ def add_layer_data_to_viewer(gui, result, return_type):
     ...     return np.random.rand(256, 256)
 
     """
-    from ..layers._source import layer_source
+    from napari._app_model.injection._processors import (
+        _add_layer_data_to_viewer,
+    )
 
-    if result is None:
-        return
-
-    viewer = find_viewer_ancestor(gui)
-    if not viewer:
-        return
-
-    with layer_source(widget=gui):
-        try:
-            viewer.layers[gui.result_name].data = result
-        except KeyError:
-            layer_type = return_type.__name__.replace("Data", "").lower()
-            adder = getattr(viewer, f'add_{layer_type}')
-            adder(data=result, name=gui.result_name)
+    if result is not None and (viewer := find_viewer_ancestor(gui)):
+        _add_layer_data_to_viewer(
+            result,
+            return_type=return_type,
+            viewer=viewer,
+            layer_name=gui.result_name,
+            source={'widget': gui},
+        )
 
 
 def add_layer_data_tuples_to_viewer(gui, result, return_type):
@@ -107,51 +106,15 @@ def add_layer_data_tuples_to_viewer(gui, result, return_type):
     ...     return [(np.ones((10,10)), {'name': 'hi'})]
 
     """
-    if result is None:
-        return
-    viewer = find_viewer_ancestor(gui)
-    if not viewer:
-        return
+    from napari._app_model.injection._processors import (
+        _add_layer_data_tuples_to_viewer,
+    )
 
-    from ..layers._source import layer_source
-    from ..utils.misc import ensure_list_of_layer_data_tuple
-    from ..utils.translations import trans
-
-    result = result if isinstance(result, list) else [result]
-    try:
-        result = ensure_list_of_layer_data_tuple(result)
-    except TypeError:
-        raise TypeError(
-            trans._(
-                'magicgui function {gui} annotated with a return type of napari.types.LayerDataTuple did not return LayerData tuple(s)',
-                deferred=True,
-                gui=gui,
-            )
+    if viewer := find_viewer_ancestor(gui):
+        _add_layer_data_tuples_to_viewer(
+            result, viewer=viewer, source={'widget': gui}
         )
 
-    with layer_source(widget=gui):
-        for layer_datum in result:
-            # if the layer data has a meta dict with a 'name' key in it...
-            if (
-                len(layer_datum) > 1
-                and isinstance(layer_datum[1], dict)
-                and layer_datum[1].get("name")
-            ):
-                # then try to update the viewer layer with that name.
-                try:
-                    layer = viewer.layers[layer_datum[1].get('name')]
-                    layer.data = layer_datum[0]
-                    for k, v in layer_datum[1].items():
-                        setattr(layer, k, v)
-                    continue
-                except KeyError:  # layer not in the viewer
-                    pass
-            # otherwise create a new layer from the layer data
-            viewer._add_layer_from_data(*layer_datum)
-
-
-_FUTURES: Set[Future] = set()
-
 
 def add_worker_data(
     widget, worker: FunctionWorker, return_type, _from_tuple=True
@@ -205,7 +168,7 @@ def add_worker_data(
     )
 
 
-def add_future_data(gui, future, return_type, _from_tuple=True):
+def add_future_data(gui, future: Future, return_type, _from_tuple=True):
     """Process a Future object from a magicgui widget.
 
     This function will be called when a magicgui-decorated function has a
@@ -229,36 +192,24 @@ def add_future_data(gui, future, return_type, _from_tuple=True):
         (only for internal use). True if the future returns `LayerDataTuple`,
         False if it returns one of the `LayerData` types.
     """
-    from .._qt.utils import Sentry
+    from napari._app_model.injection._processors import _add_future_data
 
-    # get the actual return type from the Future type annotation
-    _return_type = get_args(return_type)[0]
-
-    if _from_tuple:
-        # when the future is done, add layer data to viewer, dispatching
-        # to the appropriate method based on the Future data type.
-
-        def _on_future_ready():
-            add_layer_data_tuples_to_viewer(gui, future.result(), return_type)
-            _FUTURES.discard(future)
-
-    else:
-
-        def _on_future_ready():
-            add_layer_data_to_viewer(gui, future.result(), _return_type)
-            _FUTURES.discard(future)
-
-    # some future types (such as a dask Future) will call the callback in
-    # another thread, which wont always work here.  So we create a very small
-    # QObject that can signal back to the main thread to call `_on_done`.
-    sentry = Sentry()
-    sentry.alerted.connect(_on_future_ready)
-    future.add_done_callback(sentry.alert)
-    _FUTURES.add(future)
+    if viewer := find_viewer_ancestor(gui):
+        _add_future_data(
+            future,
+            return_type=get_args(return_type)[0],
+            _from_tuple=_from_tuple,
+            viewer=viewer,
+            source={'widget': gui},
+        )
 
 
 def find_viewer_ancestor(widget) -> Optional[Viewer]:
-    """Return the Viewer object if it is an ancestor of ``widget``, else None.
+    """Return the closest parent Viewer of ``widget``.
+
+    Priority is given to `Viewer` ancestors of ``widget``.
+    `napari.current_viewer()` is called for Widgets without a
+    Viewer ancestor.
 
     Parameters
     ----------
@@ -268,9 +219,9 @@ def find_viewer_ancestor(widget) -> Optional[Viewer]:
     Returns
     -------
     viewer : napari.Viewer or None
-        Viewer instance if one exists, else None.
+        Viewer ancestor if it exists, else `napari.current_viewer()`
     """
-    from .._qt.widgets.qt_viewer_dock_widget import QtViewerDockWidget
+    from napari._qt.widgets.qt_viewer_dock_widget import QtViewerDockWidget
 
     # magicgui v0.2.0 widgets are no longer QWidget subclasses, but the native
     # widget is available at widget.native
@@ -278,6 +229,8 @@ def find_viewer_ancestor(widget) -> Optional[Viewer]:
         parent = widget.native.parent()
     else:
         parent = widget.parent()
+    from napari.viewer import current_viewer
+
     while parent:
         if hasattr(parent, '_qt_viewer'):  # QMainWindow
             return parent._qt_viewer.viewer
@@ -285,14 +238,13 @@ def find_viewer_ancestor(widget) -> Optional[Viewer]:
             qt_viewer = parent._ref_qt_viewer()
             if qt_viewer is not None:
                 return qt_viewer.viewer
-            return None
+            return current_viewer()
         parent = parent.parent()
-    return None
+    return current_viewer()
 
 
 def proxy_viewer_ancestor(widget) -> Optional[PublicOnlyProxy[Viewer]]:
-    viewer = find_viewer_ancestor(widget)
-    if viewer:
+    if viewer := find_viewer_ancestor(widget):
         return PublicOnlyProxy(viewer)
     return None
 
@@ -321,10 +273,9 @@ def get_layers(gui: CategoricalWidget) -> List[Layer]:
     ...     return layer.data.mean()
 
     """
-    viewer = find_viewer_ancestor(gui.native)
-    if not viewer:
-        return []
-    return [x for x in viewer.layers if isinstance(x, gui.annotation)]
+    if viewer := find_viewer_ancestor(gui.native):
+        return [x for x in viewer.layers if isinstance(x, gui.annotation)]
+    return []
 
 
 def get_layers_data(gui: CategoricalWidget) -> List[Tuple[str, Any]]:
@@ -355,10 +306,9 @@ def get_layers_data(gui: CategoricalWidget) -> List[Tuple[str, Any]]:
     ...     return data.mean()
 
     """
-    from .. import layers
+    from napari import layers
 
-    viewer = find_viewer_ancestor(gui.native)
-    if not viewer:
+    if not (viewer := find_viewer_ancestor(gui.native)):
         return ()
 
     layer_type_name = gui.annotation.__name__.replace("Data", "").title()
@@ -414,12 +364,37 @@ def add_layer_to_viewer(gui, result: Any, return_type: Type[Layer]) -> None:
     ...     return napari.layers.Image(np.random.rand(64, 64))
 
     """
-    if result is None:
-        return
+    add_layers_to_viewer(gui, [result], List[return_type])
+
+
+def add_layers_to_viewer(gui, result: Any, return_type: List[Layer]) -> None:
+    """Show a magicgui result in the viewer.
+
+    Parameters
+    ----------
+    gui : MagicGui or QWidget
+        The instantiated MagicGui widget.  May or may not be docked in a
+        dock widget.
+    result : Any
+        The result of the function call.
+    return_type : type
+        The return annotation that was used in the decorated function.
+
+    Examples
+    --------
+    This allows the user to do this, and add the resulting layer to the viewer.
+
+    >>> @magicgui
+    ... def make_layer() -> List[napari.layers.Layer]:
+    ...     return napari.layers.Image(np.random.rand(64, 64))
+
+    """
+    from napari._app_model.injection._processors import _add_layer_to_viewer
 
     viewer = find_viewer_ancestor(gui)
     if not viewer:
         return
 
-    result._source = result.source.copy(update={'widget': gui})
-    viewer.add_layer(result)
+    for item in result:
+        if item is not None:
+            _add_layer_to_viewer(item, viewer=viewer, source={'widget': gui})
