@@ -1,6 +1,8 @@
 """
 This module test some of the behavior of action manager.
 """
+from unittest.mock import Mock
+
 import pytest
 
 from napari.utils.action_manager import ActionManager
@@ -48,3 +50,18 @@ def test_bind_unbind_existing_action(action_manager):
     assert action_manager.bind_shortcut('napari:test_action_1', 'X') is None
     assert action_manager.unbind_shortcut('napari:test_action_1') == ['X']
     assert action_manager._shortcuts['napari:test_action_1'] == []
+
+
+def test_bind_key_generator(action_manager):
+    def _sample_generator():
+        yield 'X'
+
+    action_manager.register_action(
+        "napari:test_action_1",
+        _sample_generator,
+        "this is a test action",
+        None,
+    )
+
+    with pytest.raises(ValueError, match="generator functions"):
+        action_manager.bind_button('napari:test_action_1', Mock())
