@@ -1,13 +1,17 @@
 import inspect
+import time
 import types
+from unittest.mock import patch
 
 import pytest
 
-from .. import key_bindings
-from ..key_bindings import (
+from napari.utils import key_bindings
+from napari.utils.key_bindings import (
     KeymapHandler,
     KeymapProvider,
     _bind_keymap,
+    _bind_user_key,
+    _get_user_keymap,
     bind_key,
     components_to_key_combo,
     normalize_key_combo,
@@ -67,7 +71,7 @@ def test_bind_key():
         return 42
 
     bind_key(kb, 'A', forty_two)
-    assert kb == dict(A=forty_two)
+    assert kb == {"A": forty_two}
 
     # overwrite
     def spam():
@@ -77,7 +81,7 @@ def test_bind_key():
         bind_key(kb, 'A', spam)
 
     bind_key(kb, 'A', spam, overwrite=True)
-    assert kb == dict(A=spam)
+    assert kb == {"A": spam}
 
     # unbind
     bind_key(kb, 'A', None)
@@ -103,7 +107,7 @@ def test_bind_key_decorator():
     def foo():
         ...
 
-    assert kb == dict(A=foo)
+    assert kb == {"A": foo}
 
 
 def test_keymap_provider():
@@ -156,7 +160,7 @@ class Foo(KeymapProvider):
         'D': ...,
     }
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.keymap = {
             'B': lambda x: setattr(x, 'B', None),  # overwrite
             'E': lambda x: setattr(x, 'E', None),  # new entry
@@ -179,6 +183,7 @@ def test_handle_single_keymap_provider():
     handler.keymap_providers = [foo]
 
     assert handler.keymap_chain.maps == [
+        _get_user_keymap(),
         _bind_keymap(foo.keymap, foo),
         _bind_keymap(foo.class_keymap, foo),
     ]
@@ -217,6 +222,32 @@ def test_handle_single_keymap_provider():
     assert not hasattr(foo, 'C')
 
 
+@patch('napari.utils.key_bindings.USER_KEYMAP', new_callable=dict)
+def test_bind_user_key(keymap_mock):
+    foo = Foo()
+    bar = Bar()
+    handler = KeymapHandler()
+    handler.keymap_providers = [bar, foo]
+
+    x = 0
+
+    @_bind_user_key('D')
+    def abc():
+        nonlocal x
+        x = 42
+
+    assert handler.active_keymap == {
+        'A': types.MethodType(foo.class_keymap['A'], foo),
+        'B': types.MethodType(foo.keymap['B'], foo),
+        'D': abc,
+        'E': types.MethodType(bar.class_keymap['E'], bar),
+    }
+
+    handler.press_key('D')
+
+    assert x == 42
+
+
 def test_handle_multiple_keymap_providers():
     foo = Foo()
     bar = Bar()
@@ -224,6 +255,7 @@ def test_handle_multiple_keymap_providers():
     handler.keymap_providers = [bar, foo]
 
     assert handler.keymap_chain.maps == [
+        _get_user_keymap(),
         _bind_keymap(bar.keymap, bar),
         _bind_keymap(bar.class_keymap, bar),
         _bind_keymap(foo.keymap, foo),
@@ -276,6 +308,7 @@ def test_inherited_keymap():
     handler.keymap_providers = [baz]
 
     assert handler.keymap_chain.maps == [
+        _get_user_keymap(),
         _bind_keymap(baz.keymap, baz),
         _bind_keymap(baz.class_keymap, baz),
         _bind_keymap(Bar.class_keymap, baz),
@@ -352,3 +385,40 @@ def test_bind_key_doc():
     doc = doc.split('Notes\n-----\n')[-1]
 
     assert doc == inspect.getdoc(key_bindings)
+
+
+def test_key_release_callback(monkeypatch):
+    called = False
+    called2 = False
+    monkeypatch.setattr(time, "time", lambda: 1)
+
+    class Foo(KeymapProvider):
+        ...
+
+    foo = Foo()
+
+    handler = KeymapHandler()
+    handler.keymap_providers = [foo]
+
+    def _call():
+        nonlocal called2
+        called2 = True
+
+    @Foo.bind_key("K")
+    def callback(x):
+        nonlocal called
+        called = True
+        return _call
+
+    handler.press_key("K")
+    assert called
+    assert not called2
+    handler.release_key("K")
+    assert not called2
+
+    handler.press_key("K")
+    assert called
+    assert not called2
+    monkeypatch.setattr(time, "time", lambda: 2)
+    handler.release_key("K")
+    assert called2
