@@ -1,7 +1,9 @@
 """Miscellaneous utility functions.
 """
+
 import builtins
 import collections.abc
+import contextlib
 import importlib.metadata
 import inspect
 import itertools
@@ -10,8 +12,7 @@ import re
 import sys
 import warnings
 from enum import Enum, EnumMeta
-from os import fspath
-from os import path as os_path
+from os import fspath, path as os_path
 from pathlib import Path
 from typing import (
     TYPE_CHECKING,
@@ -19,7 +20,10 @@ from typing import (
     Callable,
     Iterable,
     Iterator,
+    List,
     Optional,
+    Sequence,
+    Tuple,
     Type,
     TypeVar,
     Union,
@@ -27,7 +31,7 @@ from typing import (
 
 import numpy as np
 
-from ..utils.translations import trans
+from napari.utils.translations import trans
 
 if TYPE_CHECKING:
     import packaging.version
@@ -46,20 +50,35 @@ def parse_version(v) -> 'packaging.version._BaseVersion':
         return packaging.version.LegacyVersion(v)
 
 
-def running_as_bundled_app() -> bool:
-    """Infer whether we are running as a briefcase bundle."""
+def running_as_bundled_app(*, check_conda=True) -> bool:
+    """Infer whether we are running as a bundle."""
     # https://github.com/beeware/briefcase/issues/412
     # https://github.com/beeware/briefcase/pull/425
     # note that a module may not have a __package__ attribute
     # From 0.4.12 we add a sentinel file next to the bundled sys.executable
-    if (Path(sys.executable).parent / ".napari_is_bundled").exists():
+    warnings.warn(
+        trans._(
+            "Briefcase installations are no longer supported as of v0.4.18. "
+            "running_as_bundled_app() will be removed in a 0.6.0 release.",
+        ),
+        DeprecationWarning,
+        stacklevel=2,
+    )
+    if (
+        check_conda
+        and (Path(sys.executable).parent / ".napari_is_bundled").exists()
+    ):
         return True
 
+    # TODO: Remove from here on?
     try:
         app_module = sys.modules['__main__'].__package__
     except AttributeError:
         return False
 
+    if not app_module:
+        return False
+
     try:
         metadata = importlib.metadata.metadata(app_module)
     except importlib.metadata.PackageNotFoundError:
@@ -77,30 +96,40 @@ def running_as_constructor_app() -> bool:
 
 def bundle_bin_dir() -> Optional[str]:
     """Return path to briefcase app_packages/bin if it exists."""
-    bin = os_path.join(os_path.dirname(sys.exec_prefix), 'app_packages', 'bin')
-    if os_path.isdir(bin):
-        return bin
+    bin_path = os_path.join(
+        os_path.dirname(sys.exec_prefix), 'app_packages', 'bin'
+    )
+    if os_path.isdir(bin_path):
+        return bin_path
+    return None
 
 
 def in_jupyter() -> bool:
     """Return true if we're running in jupyter notebook/lab or qtconsole."""
-    try:
+    with contextlib.suppress(ImportError):
         from IPython import get_ipython
 
         return get_ipython().__class__.__name__ == 'ZMQInteractiveShell'
-    except Exception:
-        pass
     return False
 
 
 def in_ipython() -> bool:
     """Return true if we're running in an IPython interactive shell."""
-    try:
+    with contextlib.suppress(ImportError):
         from IPython import get_ipython
 
         return get_ipython().__class__.__name__ == 'TerminalInteractiveShell'
-    except Exception:
-        pass
+    return False
+
+
+def in_python_repl() -> bool:
+    """Return true if we're running in a Python REPL."""
+    with contextlib.suppress(ImportError):
+        from IPython import get_ipython
+
+        return get_ipython().__class__.__name__ == 'NoneType' and hasattr(
+            sys, 'ps1'
+        )
     return False
 
 
@@ -118,8 +147,8 @@ def ensure_iterable(arg, color=False):
     """
     if is_iterable(arg, color=color):
         return arg
-    else:
-        return itertools.repeat(arg)
+
+    return itertools.repeat(arg)
 
 
 def is_iterable(arg, color=False, allow_none=False):
@@ -127,19 +156,16 @@ def is_iterable(arg, color=False, allow_none=False):
     provided and the argument is a 1-D array of length 3 or 4 then the input
     is taken to not be iterable. If allow_none is True, `None` is considered iterable.
     """
-    if arg is None and not allow_none:
+    if (
+        (arg is None and not allow_none)
+        or isinstance(arg, str)
+        or np.isscalar(arg)
+    ):
         return False
-    elif type(arg) is str:
-        return False
-    elif np.isscalar(arg):
-        return False
-    elif color and isinstance(arg, (list, np.ndarray)):
-        if np.array(arg).ndim == 1 and (len(arg) == 3 or len(arg) == 4):
-            return False
-        else:
-            return True
-    else:
-        return True
+    if color and isinstance(arg, (list, np.ndarray)):
+        return np.array(arg).ndim != 1 or len(arg) not in [3, 4]
+
+    return True
 
 
 def is_sequence(arg):
@@ -214,18 +240,18 @@ def ensure_sequence_of_iterables(
         obj is not None
         and is_sequence(obj)
         and all(is_iterable(el, allow_none=allow_none) for el in obj)
+        and (not repeat_empty or len(obj) > 0)
     ):
         if length is not None and len(obj) != length:
-            if (len(obj) == 0 and not repeat_empty) or len(obj) > 0:
-                # sequence of iterables of wrong length
-                raise ValueError(
-                    trans._(
-                        "length of {obj} must equal {length}",
-                        deferred=True,
-                        obj=obj,
-                        length=length,
-                    )
+            # sequence of iterables of wrong length
+            raise ValueError(
+                trans._(
+                    "length of {obj} must equal {length}",
+                    deferred=True,
+                    obj=obj,
+                    length=length,
                 )
+            )
 
         if len(obj) > 0 or not repeat_empty:
             return obj
@@ -240,9 +266,9 @@ def formatdoc(obj):
         obj.__doc__ = obj.__doc__.format(
             **{**frame.f_globals, **frame.f_locals}
         )
-        return obj
     finally:
         del frame
+    return obj
 
 
 class StringEnumMeta(EnumMeta):
@@ -260,7 +286,7 @@ class StringEnumMeta(EnumMeta):
         *,
         module=None,
         qualname=None,
-        type=None,
+        type=None,  # noqa: A002
         start=1,
     ):
         """set the item value case to lowercase for value lookup"""
@@ -268,17 +294,17 @@ class StringEnumMeta(EnumMeta):
         if names is None:
             if isinstance(value, str):
                 return super().__call__(value.lower())
-            elif isinstance(value, cls):
+            if isinstance(value, cls):
                 return value
-            else:
-                raise ValueError(
-                    trans._(
-                        '{class_name} may only be called with a `str` or an instance of {class_name}. Got {dtype}',
-                        deferred=True,
-                        class_name=cls,
-                        dtype=builtins.type(value),
-                    )
+
+            raise ValueError(
+                trans._(
+                    '{class_name} may only be called with a `str` or an instance of {class_name}. Got {dtype}',
+                    deferred=True,
+                    class_name=cls,
+                    dtype=builtins.type(value),
                 )
+            )
 
         # otherwise create new Enum class
         return cls._create_(
@@ -308,7 +334,7 @@ class StringEnum(Enum, metaclass=StringEnumMeta):
     def __eq__(self, other):
         if type(self) is type(other):
             return self is other
-        elif isinstance(other, str):
+        if isinstance(other, str):
             return str(self) == other
         return NotImplemented
 
@@ -438,23 +464,26 @@ def ensure_n_tuple(val, n, fill=0):
 
 
 def ensure_layer_data_tuple(val):
-    if not (isinstance(val, tuple) and (0 < len(val) <= 3)):
-        raise TypeError(
-            trans._(
-                'Not a valid layer data tuple: {value!r}',
-                deferred=True,
-                value=val,
-            )
-        )
+    msg = trans._(
+        'Not a valid layer data tuple: {value!r}',
+        deferred=True,
+        value=val,
+    )
+    if not isinstance(val, tuple) and val:
+        raise TypeError(msg)
+    if len(val) > 1:
+        if not isinstance(val[1], dict):
+            raise TypeError(msg)
+        if len(val) > 2 and not isinstance(val[2], str):
+            raise TypeError(msg)
     return val
 
 
-def ensure_list_of_layer_data_tuple(val):
-    if isinstance(val, list) and len(val):
-        try:
+def ensure_list_of_layer_data_tuple(val) -> List[tuple]:
+    # allow empty list to be returned but do nothing in that case
+    if isinstance(val, list):
+        with contextlib.suppress(TypeError):
             return [ensure_layer_data_tuple(v) for v in val]
-        except TypeError:
-            pass
     raise TypeError(
         trans._('Not a valid list of layer data tuples!', deferred=True)
     )
@@ -466,6 +495,10 @@ def _quiet_array_equal(*a, **k):
         return np.array_equal(*a, **k)
 
 
+def _pandas_dataframe_equal(df1, df2):
+    return df1.equals(df2)
+
+
 def _arraylike_short_names(obj) -> Iterator[str]:
     """Yield all the short names of an array-like or its class."""
     type_ = type(obj) if not inspect.isclass(obj) else obj
@@ -504,6 +537,7 @@ def pick_equality_operator(obj) -> Callable[[Any, Any], bool]:
         'dask.Delayed': operator.is_,  # dask.delayed.Delayed
         'zarr.Array': operator.is_,  # zarr.core.Array
         'xarray.DataArray': _quiet_array_equal,  # xarray.core.dataarray.DataArray
+        'pandas.DataFrame': _pandas_dataframe_equal,  # pandas.DataFrame.equals
     }
 
     for name in _arraylike_short_names(obj):
@@ -689,3 +723,63 @@ def install_certifi_opener():
     https_handler = request.HTTPSHandler(context=context)
     opener = request.build_opener(https_handler)
     request.install_opener(opener)
+
+
+def reorder_after_dim_reduction(order: Sequence[int]) -> Tuple[int, ...]:
+    """Ensure current dimension order is preserved after dims are dropped.
+
+    This is similar to :func:`scipy.stats.rankdata`, but only deals with
+    unique integers (like dimension indices), so is simpler and faster.
+
+    Parameters
+    ----------
+    order : Sequence[int]
+        The data to reorder.
+
+    Returns
+    -------
+    Tuple[int, ...]
+        A permutation of ``range(len(order))`` that is consistent with the input order.
+
+    Examples
+    --------
+    >>> reorder_after_dim_reduction([2, 0])
+    (1, 0)
+
+    >>> reorder_after_dim_reduction([0, 1, 2])
+    (0, 1, 2)
+
+    >>> reorder_after_dim_reduction([4, 0, 2])
+    (2, 0, 1)
+    """
+    # A single argsort works for strictly increasing/decreasing orders,
+    # but not for arbitrary orders.
+    return tuple(argsort(argsort(order)))
+
+
+def argsort(values: Sequence[int]) -> List[int]:
+    """Equivalent to :func:`numpy.argsort` but faster in some cases.
+
+    Parameters
+    ----------
+    values : Sequence[int]
+        The integer values to sort.
+
+    Returns
+    -------
+    List[int]
+        The indices that when used to index the input values will produce
+        the values sorted in increasing order.
+
+    Examples
+    --------
+    >>> argsort([2, 0])
+    [1, 0]
+
+    >>> argsort([0, 1, 2])
+    [0, 1, 2]
+
+    >>> argsort([4, 0, 2])
+    [1, 2, 0]
+    """
+    return sorted(range(len(values)), key=values.__getitem__)
