@@ -8,9 +8,8 @@ from contextlib import suppress
 from typing import List, Union
 
 import npe2
-from pydantic import validator
-from pydantic.color import Color
 
+from napari._pydantic_compat import Color, validator
 from napari._vendor import darkdetect
 from napari.resources._icons import (
     PLUGIN_FILE_NAME,
